### Carbon and nitrogen cycling in Yedoma permafrost controlled by microbial functional limitations
## Sylvain Monteux, Frida Keuper, Sebastien Fontaine, Konstantin Gavazov, Sara Hallin, Jaanis Juhanson, Eveline J. Krab, Sandrine Revaillot, Erik T. Verbruggen, Josefine Walz, James T. Weedon, Ellen Dorrepaal
# Nature Geoscience - doi:10.1038/s41561-020-00662-4
#
# This R script aims at reproducing figures presented throughout the article and its supplementary materials.
# This script was tested in both R v3.6.3 and v4.0.3
# If you have just downloaded this, the R/ folder should contain the files used for producing the figures found in the article.
# If you have previously followed the bioinformatics pipeline to reproduce the community data based on raw sequences, the Rnew/ folder will contain a different set of files. In that case, please uncomment the "read.table" lines containing Rnew to run the script with the newly-obtained files
# The output of this script will consist in a "Figures" folder containing Figures 1-3 and Extended Data Figures 1-10 (panel by panel), Table 1, as well as a "SourceData" folder containing the Source Data for Figures 1-3
# These can be used to reproduce the figures found in the article, and may slightly vary due to stochastic variations during e.g. rarefactions, without affecting the main results or findings.
# For questions regarding the manuscript or analyses, please contact the co-corresponding authors [Sylvain Monteux](url:mailto:sylvain.monteux@slu.se) and [Frida Keuper](mailto:frida.keuper@inrae.fr)
# For bug reports or questions regarding the scripts, please contact [Sylvain Monteux](url:mailto:sylvain.monteux@slu.se). 


# Structure:
  # 0. Dependencies, source files, data preparation
  # 1-3. Figures
    # 1. Figure 1
    # 2. Figure 2
    # 3. Figure 3
  # 4-13. Extended Data
    # 4. Extended Data Figure 1 (Table)
    # 5. Extended Data Figure 2
    # 6. Extended Data Figure 3 (Table)
    # 7. Extended Data Figure 4
    # 8. Extended Data Figure 5
    # 9. Extended Data Figure 6
    # 10. Extended Data Figure 7 (Table)
    # 11. Extended Data Figure 8
    # 12. Extended Data Figure 9
    # 13. Extended Data Figure 10
  # 14. Table 1
  # 15. Information supporting response to referees

### 0. Dependencies, source files, data preparation ----
lapply(list('vegan', 'ggplot2','ggrepel','car','plyr','dplyr',
            'emmeans','reshape','RColorBrewer','randomForest',
            'rfPermute', 'mvabund','dunn.test', 'VSURF', 'AICcmodavg'), require, character.only = TRUE) # check dependencies
setwd() # set working directory to where the script is
system(command="mkdir SourceData") # If using Windows you'll need to manually create a new "SourceData" folder
system(command="mkdir Figures") # If using Windows you'll need to manually create a new "Figures" folder

# 16S mapping file
map16s<-read.table("Metadata/MonteuxKeuper_Mapping.txt",
                   header=T,
                   sep=",",
                   dec=",")
      # Former_sample_designation and ref are respectively numbers and names associated to each sample in the experiment
      # ID_unique_extraction is the unique identifier of DNA extracts
      # SampleID and FungiXname are the sample identifiers assigned to each sample throughout the VSEARCH / QIIME pipeline for bacteria and fungi samples
      # Harvest and day are the qualitative and quantitative day numbers
      # TDC, Cmic_total, NO3_N, NH4_N and DIN are expressed in mg per kg soil DW
map16s$trt<-as.factor(map16s$trt)
map16s$Harvest<-as.factor(map16s$Harvest) 
map16s$harvest<-factor(map16s$Harvest,levels=levels(map16s$Harvest)[c(6,1,2,3,4,5)]) # Re-order the Harvest level to be chronological

# incubation data
res<-read.csv("Metadata/MonteuxKeuper_Respiration_short.csv",sep="\t")
      # CO2_rate and CO2_rate_interp are the measured and interpolated CO2 production rates presented in EDF6
      # CO2_cumulative_interp is the cumulative CO2 production presented in Fig 2a and EDF4
      # CO2_rate_detrended is the measured CO2 production rate (CO2_rate) divided by the average of all measurements within each time point, used in RandomForest analyses and multiple linear regressions
      # CO2 production rates are expressed in mg-CO2 per kg soil DW per day, cumulative CO2 production is expressed in mg-CO2 per kg soil DW
res$trt<-as.factor(res$trt)
levels(res$trt)<-c("Soil transfer","Control")
res$trt<-ordered(res$trt,levels=levels(res$trt)[c(2,1)])
res$co2<-res$CO2_cumulative_interp # cumulative CO2 production, renamed for convenience
res$co2_det<-res$CO2_rate_detrended_interp # co2 divided by the average in its harvest, renamed for convenience
res$co2_rate<-res$CO2_rate_interp # interpolated CO2 production rate2, renamed for convenience
levels(map16s$harvest)<-c("Pre-","1","15","30","71","161") # Re-label the level labels to correspond to "Days since transfer"
map16s$Treatment<-map16s$trt
levels(map16s$Treatment)<-c("Control","Soil transfer") # Rename the treatments
rownames(map16s)<-map16s$SampleID # Give identifiable row names
res$SampleID<-as.character(res$prox_Xname)
map16s_wmet<-map16s[match(res$SampleID,
                          rownames(map16s) ),] # Re-order rows and remove those without DNA data
all.equal(rownames(map16s_wmet),res$SampleID)
map16s_wmet$NO32<-ifelse(map16s_wmet$NO3_N < 0.5, NA, map16s_wmet$NO3_N ) # A plotting variable where the below detection limit values of nitrate+nitrite are NA
map16s_wmet$CO2<-res$co2 # Add cumulative CO2 production (mg / kg DW)  to the 16S mapping file
map16s_wmet$CO2_det<-res$co2_det # add detrended cumulative CO2 production rates
map16s_wmet$CO2_rate<-res$co2_rate # add CO2 production rates

# 16S OTU table
otutab<-read.table("R/Yedoma_5000_nofail_ggtax.otu",
                   header=T,
                   row.names = 1,
                   sep="\t")
# otutab<-read.table("Rnew/Yedoma_5000_nofail_ggtax.otu",
#                    header=T,
#                    row.names = 1,
#                    sep="\t")
otutab_for_mng<-otutab[,names(otutab) %in% rownames(map16s_wmet)]
map16s_wmet_wdna<-subset(map16s_wmet,SampleID %in% names(otutab_for_mng))
map16s_wmet_wdna<-map16s_wmet_wdna[match(names(otutab_for_mng),rownames(map16s_wmet_wdna)),]

# 16S Differential abundance (DESeq)
deseqF<-read.table("R/diff_abund_YvI_all_harvests.txt",
                   header=T,
                   row.names = 1,
                   sep="\t")
# deseqF<-read.table("Rnew/diff_abund_YvI_all_harvests.txt",
#                    header=T,
#                    row.names = 1,
#                    sep="\t")
deseqH0<-read.table("R/diff_abund_YvI_H0.txt",header=T,row.names = 1,sep="\t")
# deseqH0<-read.table("Rnew/diff_abund_YvI_H0.txt",header=T,row.names = 1,sep="\t")
deseqH1<-read.table("R/diff_abund_YvI_H1.txt",header=T,row.names = 1,sep="\t")
# deseqH1<-read.table("Rnew/diff_abund_YvI_H1.txt",header=T,row.names = 1,sep="\t")
deseqH2<-read.table("R/diff_abund_YvI_H2.txt",header=T,row.names = 1,sep="\t")
# deseqH2<-read.table("Rnew/diff_abund_YvI_H2.txt",header=T,row.names = 1,sep="\t")
deseqH3<-read.table("R/diff_abund_YvI_H3.txt",header=T,row.names = 1,sep="\t")
# deseqH3<-read.table("Rnew/diff_abund_YvI_H3.txt",header=T,row.names = 1,sep="\t")
deseqH4<-read.table("R/diff_abund_YvI_H4.txt",header=T,row.names = 1,sep="\t")
# deseqH4<-read.table("Rnew/diff_abund_YvI_H4.txt",header=T,row.names = 1,sep="\t")

# 16S taxa summary
tax2<-read.table("R/Yedoma_5000_nofail_ggtax_L2.txt",header=T,row.names=1,comment.char = "@") # Phylum level
# tax2<-read.table("Rnew/Yedoma_5000_nofail_ggtax_L2.txt",header=T,row.names=1,comment.char = "@") # Phylum level
tax3<-read.table("R/Yedoma_5000_nofail_ggtax_L3.txt",header=T,row.names=1,comment.char = "@") # Class level
# tax3<-read.table("Rnew/Yedoma_5000_nofail_ggtax_L3.txt",header=T,row.names=1,comment.char = "@") # Class level
tax2_cat<-rbind(tax2,
                tax3[min(grep("*proteo*",rownames(tax3))):max(grep("*proteo*",rownames(tax3))),])
rownames(tax2_cat)<-gsub("Proteobacteria;c__","",
                         gsub("k__Bacteria;","",
                              gsub("p__", "", 
                                   gsub("k__Archaea;","",
                                        rownames(tax2_cat)
                                   )
                              )
                         )
)
ttax2<-as.data.frame(t(tax2_cat))
ttax2<-ttax2[match(rownames(map16s)[-2],rownames(ttax2)),]

# 16S alpha diversity 
alpha_16s_div<-read.table("R/alpha_div_Yedoma.txt")   
# alpha_16s_div<-read.table("Rnew/alpha_div_Yedoma.txt")   
alpha_16s_div<-alpha_16s_div[match(rownames(map16s)[-2],
                                   rownames(alpha_16s_div) ),]
all.equal(row.names(alpha_16s_div),as.character(map16s$SampleID[-2]))
alpha_16s_div$Treatment<-map16s$Treatment[-2]
alpha_16s_div$Days<-map16s$harvest[-2]

# 16S alpha diversity response to rarefaction depth
rarchao<-read.table("R/16schao1.txt",sep="\t",h=T,r=1,na.strings = "n/a")
# rarchao<-read.table("Rnew/16schao1.txt",sep="\t",h=T,r=1,na.strings = "n/a")

# Data subset for cumulative respiration figure and stats
res_full<-read.csv("Metadata/MonteuxKeuper_Respiration_long.csv",h=T,sep="\t")
      # Variables are as described at L52-53
      # This file includes all time points for CO2 measurements, not only those correspondig to destructive samplings
      # These CO2 production rates are presented in EDF6 for the Control and Soil transfer treatments
      # The cumulative CO2 production for all treatments are presented in EDF4
res_full$set<-car::recode(res_full$pot,"58:75='A';else='B'")
resp161<-subset(res_full,day==161)
resp161$trt<-as.factor(resp161$trt)
resp161$soil_type<-as.factor(resp161$soil_type)
levels(resp161$soil_type)<-c("Inoculum","Permafrost")
resp161$cellulose<-as.factor(resp161$cellulose)
resp161$nutrients<-as.factor(resp161$nutrients)
resp161$inoc<-as.factor(resp161$inoc)
levels(resp161$cellulose)<-c("No","Yes")
levels(resp161$nutrients)<-c("No","Yes")
levels(resp161$inoc)<-c("No","Yes")

# PLFA data
plin<-read.table(file="Metadata/MonteuxKeuper_PLFA.txt")
      # Sum of PLFA markers within each group as described in Methods
      # Data are expressed in nmol PLFA per g soil DW
plin$Treatment<-as.factor(plin$Treatment)
plin$Days<-as.factor(plin$harvest)
levels(plin$Days)<-c("1","30","161","15","71")
plin$Days<-ordered(plin$Days,levels=levels(plin$Days)[c(1,4,2,5,3)])
levels(plin$Treatment)<-c("Control","Soil transfer")


# ITS mapping file amd alpha-diversity
alpha_its_div<-read.table("R/its_alpha_div.txt")     
# alpha_its_div<-read.table("Rnew/its_alpha_div.txt")     
mapits<-subset(map16s,FungiXname %in% rownames(alpha_its_div))
rownames(mapits)<-mapits$FungiXname
mapits<-mapits[match(rownames(alpha_its_div),rownames(mapits)),]
mapits_wmet<-subset(mapits,FungiXname %in% res$prox_Xname_fungi)
alpha_its_div$Treatment<-mapits$Treatment
alpha_its_div$harvest<-mapits$harvest

# ITS taxa summary (class-level)
fun_tax<-read.table("R/Yedoma_ITS_5k_wtax_L3.txt",header=T,row.names=1,comment.char = "@")
# fun_tax<-read.table("Rnew/Yedoma_ITS_5k_wtax_L3.txt",header=T,row.names=1,comment.char = "@")

# ITS OTU table
otutabf<-read.table("R/Yedoma_ITS_5k_wtax.otu",header=T,row.names = 1)
# otutabf<-read.table("Rnew/Yedoma_ITS_5k_wtax.otu",header=T,row.names = 1)
otutabf_for_mng<-otutabf[,names(otutabf) %in% rownames(mapits_wmet)]

# ITS Differential abundance (DESeq)
deseqFun<-read.table("R/diff_abund_YvI_ITS.txt",header=T,row.names = 1,sep="\t") # filtered with only OTUs present in at least 10% of samples
# deseqFun<-read.table("Rnew/diff_abund_YvI_ITS.txt",header=T,row.names = 1,sep="\t") # filtered with only OTUs present in at least 10% of samples
deseqFunH0<-read.table("R/diff_abund_YvI_ITS_H0.txt",header=T,row.names = 1,sep="\t") 
# deseqFunH0<-read.table("Rnew/diff_abund_YvI_ITS_H0.txt",header=T,row.names = 1,sep="\t") 
deseqFunH1<-read.table("R/diff_abund_YvI_ITS_H1.txt",header=T,row.names = 1,sep="\t") 
# deseqFunH1<-read.table("Rnew/diff_abund_YvI_ITS_H1.txt",header=T,row.names = 1,sep="\t") 
deseqFunH4<-read.table("R/diff_abund_YvI_ITS_H4.txt",header=T,row.names = 1,sep="\t") 
# deseqFunH4<-read.table("Rnew/diff_abund_YvI_ITS_H4.txt",header=T,row.names = 1,sep="\t") 

# ITS alpha diversity response to rarefaction depth
rarchao_fun<-read.table("R/itschao1.txt",sep="\t",h=T,r=1,na.strings = "n/a")
# rarchao_fun<-read.table("Rnew/itschao1.txt",sep="\t",h=T,r=1,na.strings = "n/a")

# qPCR data for 16S rRNA gene, archaeal amoA and bacterial amoA
qpcr<-read.table("Metadata/MonteuxKeuper_qPCR.txt",h=T)
      # Gene copy numbers per g soil DW used in Fig 3, Table 1, EDF3, and EDT3
      # Mult_factor_gDW indicates the conversion factor used to obtain these data from the average gene copy numbers in two reactions, accounting for amount of soil DW used for DNA extraction and dilution factor of the DNA template used in qPCR reaction
      # AOA_DL is archaeal amoA gene
      # AOB_DL is bacterial amoA gene
      # X16S_DL is 16S rRNA gene
qpcr$Harvest<-as.factor(qpcr$Harvest)
qpcr$Harvest<-factor(qpcr$Harvest,levels=levels(qpcr$Harvest)[c(6,1,2,4,5,3)])
qpcr$Sum_abs<-rowSums(qpcr[,7:8],na.rm=T) # Sum of archaeal and bacterial amoA
qpcr_NAs<-melt(qpcr[,c(3:4,6:8)])
levels(qpcr_NAs$variable)<-c("16S (V3)","Archaeal amoA","Bacterial amoA")
levels(qpcr_NAs$Treatment)<-c("Control","Soil transfer")

# Reproduced incubation experiment CO2 data for EDF 5
EDF8<-read.table("Metadata/MonteuxKeuper_EDF8.txt",h=T,r=1)
      # CO2 is the CO2 concentration measured at day 389
      # Flux_ppm_h is the increase in CO2 concentration per hour since last flushing with CO2-free synthetic air
      # Flux_per_gDW is Flux_ppm_h expressed per g soil DW
      # Cum_prod_mgC is the cumulative CO2 production in mgC since the onset of the experiment
      # Cum_prod_mgC_per_gDW is Cum_prod_mgC expressed per g soil DW (this is multiplied by 1000 in EDF5 to be presented per kg soil DW)
EDF8$Treatment<-as.factor(EDF8$Treatment)
EDF8$Treatment<-factor(EDF8$Treatment,levels=levels(EDF8$Treatment)[c(4,1:3,5)])

#### 0. Axes labels, plotting tweaks, color palette and convenience function ----

# Fig 1
ds2b_yl<-expression(paste('Log'[2]*'(fold-change) with soil transfer'))

# Fig 2
yl_2a<-expression(paste('mg-C . kg(soil DW)'^'-1','. day'^'-1')) # y axis label
yl_fig_2_bot<-expression(paste('mg-N . kg(soil DW)'^'-1'))

# Fig 3
annot_amoA<-data.frame(variable=c(rep("Archaeal amoA",5),rep("Bacterial amoA",4)),
                       x=c(2,3,4,5,6,3,4,5,6),
                       y=1e4,
                       lab=c("","","","","","a","a","ab","b"),
                       Treatment="Control")

bks<-10^(-10:10) # Breaks for log-scale plotting
mbks <- rep(1:9, 21)*(10^rep(-10:10, each=9)) # Minor breaks for log-scale plotting

# EDF4
xl_deltacod<-expression(paste(bold("|Soil transfer - Control|")))# y axis label
yl_edf2_top<-expression(paste('mg-C . kg(soil DW)'^'-1'))

# EDF5
yl_edf_5_top<-expression(paste('mg-SOM-derived C . kg(soil DW)'^'-1'))
EDF5_anova_header<-expression(paste('Permafrost cumulative CO'[2],' production ANOVA'))
EDF5_anova_inoc<-expression(paste(bold('Soil transfer (+36%)'),' - F=551.7, ',italic(P),'<10'^{-13}))
EDF5_anova_cell<-expression(paste(bold('13C-cellulose (+9%)'),' - F=42.2, ',italic(P),'<10'^{-5}))
EDF5_anova_nutr<-expression(paste('Nutrients (-2%) - F=2.1, ',italic(P),'=0.17'))
EDF5_anova_inter<-expression(paste('Interactions - F<2, ',italic(P),'>0.18'))

# EDF8
ylab389<-expression(paste('mg-CO'[2]*'-C. kg(soil DW)'^'-1',' -  Day 389'))
posthoc389df_yedo<-data.frame(x=c(1,2,3,4,5),
                              y=1700,
                              labs=c("a","b","c","d","e"),
                              Soil_type="Yedoma",
                              Treatment="Control")
posthoc389df_pf<-data.frame(x=c(2,1,2,1,2,1),
                           y=c(0.2,0.2,
                               2,2,
                               0.37,0.37),
                           labs=c("**","OMC%\n1.18 +/- 0.04",
                                  "**","OMC%\n12.80 +/- 0.07",
                                  "***","OMC%\n3.56 +/- 0.05"),
                           Soil_type=c("Permafrost1","Permafrost1",
                                       "Permafrost2","Permafrost2",
                                       "Permafrost3","Permafrost3"),
                           face=c("bold","plain"),
                           size=c(2,1.6),
                           Treatment="Control")

# EDF9
yl_edf9_top2<-expression(paste('mg-C . kg(soil DW)'^'-1','. day'^'-1')) # y axis label


### 0. Color palette and convenience function ----
phyla.pal<-c("Acidobacteria"="#a6cee3", 
             "Actinobacteria"="#1f78b4",
             "Bacteroidetes"="#b2df8a",
             "Chloroflexi"="#33a02c",
             "Firmicutes"="#8c510a",
             "Gemmatimonadetes"="#fdbf6f",
             "Nitrospirae"="#bf812d",
             "Alphaproteobacteria"="#c7eae5",
             "Betaproteobacteria"="#80cdc1",
             "Gammaproteobacteria"="#35978f",
             "Deltaproteobacteria"="#01665e",
             "Verrucomicrobia"="#b15928", 
             "Other"= "grey")
fung.pal<-c("Asco. Archaeorhizomycetes" ="#8DD3C7",
            "Asco. Dothideomycetes" =   "#FFFFB3",
            "Asco. Eurotiomycetes" = "#BEBADA" ,
            "Asco. Leotiomycetes" = "#01665e"   ,
            "Asco. Pezizomycetes" = "#80B1D3",
            "Asco. Sordariomycetes" = "#FDB462",  
            "Asco. unidentified" = "#B3DE69"    ,
            "Basidio. Agaricomycetes" = "#FCCDE5",
            "Basidio. Tremellomycetes" ="#D9D9D9",
            "Zygo. Incertae_sedis" = "#BC80BD"   ,
            "Undetermined fungi" = "#CCEBC5"    ,
            "Other" = "#FFED6F"  )                
             
clean_otu_taxonomy_proteo<-function(x){ # used to clean taxonomy names of OTUs into phylum level (class for Proteobacteria)
  gsub("k__Bacteria","Unclassified",
       gsub("; o__.*","",
            gsub("; c__.*","",
                 gsub(".*c__Delta","Delta",
                      gsub(".*c__Alpha","Alpha",
                           gsub(".*c__Beta","Beta",
                                gsub(".*c__Gamma","Gamma",
                                     gsub("k__.*p__","",
                                          gsub("; NA.*", "", 
                                               x)
                                     )
                                )
                           )
                      )
                 )
            )
       )
  )
}


#### 1. Figure 1: Effects of soil transfer on bacterial communities ----
### 1a. Fig. 1A: Differential abundance (DESeq) of OTUs between treatments ----
deseqF$otu<-rownames(deseqF)
psubF_init<-filter(deseqF,
                   padj < 0.05)
rownames(psubF_init)<-psubF_init$otu
otutab_for_mng$otu<-rownames(otutab_for_mng)
otusubF<-filter(otutab_for_mng,
                otu %in% psubF_init$otu)
psubF<-filter(psubF_init,
              otu %in% otusubF$otu)
rownames(otusubF)<-otusubF$otu
rownames(psubF)<-psubF$otu
otusubF<-otusubF[match(rownames(psubF),
                       rownames(otusubF)),]
all.equal(rownames(otusubF),rownames(psubF))
psubF$ab_rar1000<-rowSums(otusubF[,1:29])
psubF$ab_rar1000_pc<-(psubF$ab_rar1000/sum(otutab_for_mng[,1:29]))*100 ### abundance of the OTU in the total rarefied dataset in %
otusfullF<-psubF$taxonomy
phyl_namesfullF <- clean_otu_taxonomy_proteo(otusfullF)

psubF$phyla_temp<-recode(as.factor(phyl_namesfullF),
                         "Acidobacteria"="Acidobacteria",
                         "Actinobacteria"="Actinobacteria",
                         "Bacteroidetes"="Bacteroidetes",
                         "Chloroflexi"="Chloroflexi",
                         "Firmicutes"="Firmicutes",
                         "Gemmatimonadetes"="Gemmatimonadetes",
                         "Nitrospirae"="Nitrospirae",
                         "Alphaproteobacteria"="Alphaproteobacteria",
                         "Betaproteobacteria"="Betaproteobacteria",
                         "Gammaproteobacteria"="Gammaproteobacteria",
                         "Deltaproteobacteria"="Deltaproteobacteria",
                         "Verrucomicrobia"="Verrucomicrobia",
                         .default="Other")
psubF$Phyla<-factor(psubF$phyla_temp,
                    levels=c("Acidobacteria",
                             "Actinobacteria",
                             "Bacteroidetes",
                             "Chloroflexi",
                             "Firmicutes",
                             "Gemmatimonadetes",
                             "Nitrospirae",
                             "Alphaproteobacteria",
                             "Betaproteobacteria",
                             "Gammaproteobacteria",
                             "Deltaproteobacteria",
                             "Verrucomicrobia", 
                             "Other" )
)

# Rearrange the dataset by decreasing Phyla and Fold-change for readability
psubF_final<-arrange(psubF,desc(Phyla),
                     (-log2FoldChange))
rownames(psubF_final)<-c(1:length(rownames(psubF_final)))  
psubF_final$fact_abund<-ifelse(psubF_final$ab_rar1000_pc>0.5,
                               "High",
                               "Low")
psubF_final$fact_abund2<-ifelse(rownames(psubF_final) %in% grep("*Nitro*",psubF_final$taxonomy),
                                "Nitrifier", 
                                psubF_final$fact_abund)
ggplot(psubF_final,
       aes(x=as.numeric(rownames(psubF_final)),
           y=-log2FoldChange))+
  theme_bw()+
  xlab(paste(length(psubF_final$otu),"bacterial OTUs affected by soil transfer - DESeq2 NB-GLM Wald test"))+
  ylab(ds2b_yl)+
  geom_bar(aes(fill=Phyla),
           stat="identity",
           width=1)+
  scale_fill_manual(values=phyla.pal)+
  theme(legend.position="bottom",
        legend.justification=c(0,1),
        legend.box="vertical",
        axis.text.y=element_blank(),
        axis.ticks.y=element_blank(),
        legend.key.size=unit(0.4,"cm"),
        text=element_text(size=10),
        panel.grid=element_blank(),
        panel.background=element_rect(fill="NA")
  )+
  geom_segment(data=psubF_final,
               aes(x=as.numeric(rownames(psubF_final)),
                   xend=as.numeric(rownames(psubF_final)),
                   y=-1,
                   yend=0,
                   col=fact_abund2),
               arrow=arrow(type = "closed",
                           length=unit(0.15,"cm"),
                           angle=20),
               lwd=0.5)+
  geom_point(data=psubF_final,
             aes(x=as.numeric(rownames(psubF_final)),
                 y=0,
                 alpha=fact_abund2),
             show.legend = F,
             pch=4)+
  scale_alpha_manual(values=c(1,0,0))+
  scale_size(range=c(0.1,3),
             breaks=c(0,0.25,0.5,1,6,12))+
  scale_color_manual(values=c("NA","NA","black"))+
  guides(color=F,
         fill=F)+
  coord_flip()
ggsave("Figures/Fig_1A.pdf",width=60,height=140,unit="mm",device=cairo_pdf)
write.table(psubF_final,"SourceData/SourceData_Fig_1A.txt",row.names = F)

# In text we discuss the number of changing OTUs:
length(psubF$baseMean)/length(deseqF$baseMean)
# and which proportions of the total observations these OTUs represent:
sum(psubF$ab_rar1000)/sum(otutab[,-c(6:8,33:35)]) # value used in the article; normalized counts (rarefaction depth 5000). This line excludes pre-incubation samples
sum(psubF$baseMean)/sum(deseqF$baseMean) # non-normalized counts, for information
# and the number of nitrifiers
table(psubF_final$fact_abund2)['Nitrifier']

### 1b. Fig. 1B: Taxa summary of bacterial phyla/classes ----
all.equal(rownames(ttax2),as.character(map16s$SampleID)[-2])
big_ordered_dat <- ttax2[,order(colSums(ttax2), decreasing=T)]
ordered_dat<-big_ordered_dat[,c(2:13)] # Remove column 1 (Proteobacteria) as they duplicate with class-level proteobacteria
# keep the same phyla than in DESeq, although Fibrobacteres are slightly more abundant than Nitrospirae 
ordered_dat$Other<-rowSums(big_ordered_dat[,c(14:35)]) 
ordered_dat$Treatment=map16s$Treatment[-2]
ordered_dat$Harvest=map16s$harvest[-2]
ordered_dat.melt<-melt(ordered_dat,variable_name = "phyl_int",
                       id.vars = c("Treatment","Harvest"))
levels(ordered_dat.melt$Treatment)<-c("Control soil", "Soil transfer")
ordered_dat.melt$Phyla<-factor(ordered_dat.melt$phyl_int, 
                               levels=(c("Acidobacteria",
                                         "Actinobacteria",
                                         "Bacteroidetes",
                                         "Chloroflexi",
                                         "Firmicutes",
                                         "Gemmatimonadetes",
                                         "Nitrospirae",
                                         "Alphaproteobacteria",
                                         "Betaproteobacteria",
                                         "Gammaproteobacteria",
                                         "Deltaproteobacteria",
                                         "Verrucomicrobia",
                                         "Other")))
ggplot(ordered_dat.melt, 
       aes(x = Harvest))+ 
  theme_bw() +
  facet_wrap(~Treatment,
             nrow=1)+
  xlab("")+
  ylab("Relative abundance")+
  geom_bar(aes(weight=value,
               fill = Phyla),
           position = 'fill',
           width=0.7) + 
  scale_fill_manual(values=phyla.pal)+
  guides(fill=guide_legend("Phylum/class",
                           title.position="top",
                           title.hjust = 0.5,
                           ncol=2),
         lty=F)+
  geom_vline(aes(xintercept=1.5,lty=Treatment))+
  scale_linetype_manual(values=c(3,1))+
  scale_x_discrete(labels=c("Inoc."="Inoc."))+
  theme(legend.position="top",
        text=element_text(size=10), 
        legend.key=element_blank(),
        legend.key.size=unit(4,"mm"),
        panel.grid=element_blank(),
        axis.text.x=element_text(size=7),
        axis.text.y=element_text(size=7),
        strip.background=element_rect(fill="grey90"))
ggsave("Figures/Fig_1B.pdf",width=60,height=90,unit="mm",device=cairo_pdf) 
write.table(ordered_dat.melt,"SourceData/SourceData_Fig1B.txt",row.names = F)

### 1c. Fig. 1C: bacterial alpha diversity ----
alpha_16s_div$Soil<-factor(car::recode(paste(alpha_16s_div$Treatment,alpha_16s_div$Days),
                                       '"Soil transfer Pre-"="Donor soil";else="Permafrost"'))
levels(alpha_16s_div$Soil)
alpha_16s_div$Graph<-factor(droplevels(interaction(alpha_16s_div$Soil,
                                                   alpha_16s_div$Treatment)),
                            levels=levels(droplevels(interaction(alpha_16s_div$Soil,
                                                                 alpha_16s_div$Treatment)))[c(1,3,2)], 
                            labels=c("Control soil","Soil transfer","Donor soil"))
levels(alpha_16s_div$Graph)
ggplot(alpha_16s_div,
       aes(x=Days,
           y=ace,
           col=Graph,
           pch=Graph))+
  stat_summary(size=0.3,
               position=position_dodge(0))+
  scale_color_manual(values=c("grey60",
                              "grey10",
                              "grey10"))+
  scale_shape_manual(values=c("Control soil"=16,
                              "Soil transfer"=16,
                              "Donor soil"=17))+
  guides(col=guide_legend("",reverse = F,override.aes=list(pch=c(16,16,17))),
         pch=F)+
  theme(legend.key=element_blank(), 
        panel.background=element_rect(fill=NA,
                                      color="black"),
        panel.grid=element_blank(),
        text=element_text(size=10),
        legend.margin=NULL,
        legend.box.margin=NULL,
        legend.box=NULL,
        legend.background=element_rect(colour="black",fill=NA),
        legend.box.background = element_blank(),
        legend.key.size=unit(0.4,"cm"),
        legend.position=c(0.717,0.85))+ 
  geom_vline(aes(xintercept=1.5),lty=1)+
  xlab("Days since transfer")+
  ylab("Alpha diversity (ACE)")
ggsave("Figures/Fig_1C.pdf",width=65,height=50,unit="mm",device=cairo_pdf)  
write.table(alpha_16s_div,"SourceData/SourceData_Fig_1C.txt",row.names = F)


#### 2. Figure 2: Carbon and nitrogen ----
### 2a. Fig. 2a: CO2 production rates and cumulative ----

# Calculate mean +/- s.e.m. for cumulative production bars
Inoc_y<-mean(res$CO2_cumulative_interp[c(25:27)])
Inoc_se<-sd(res$CO2_cumulative_interp[c(25:27)])/sqrt(2)
Inoc_ymin<-Inoc_y-Inoc_se
Inoc_ymax<-Inoc_y+Inoc_se
Ctrl_y<-mean(res$CO2_cumulative_interp[c(28:30)])
Ctrl_se<-sd(res$CO2_cumulative_interp[c(28:30)])/sqrt(2)
Ctrl_ymin<-Ctrl_y-Ctrl_se
Ctrl_ymax<-Ctrl_y+Ctrl_se

ggplot(res,aes(x=as.factor(day),y=CO2_rate,fill=trt))+
  stat_summary(fun.data =  mean_se,
               size=0.2,
               width = 0,
               color = "black",
               geom="errorbar")+
  stat_summary(fun.data =  mean_se,
               size = 1.5,
               color = "black",
               geom = "point",
               pch = 21)+
  scale_fill_manual(values=c("white","darkgrey"),name=NULL)+
  scale_y_continuous(breaks=c(1,5,10,20),minor_breaks = c(1:20))+
  coord_trans(y="log10")+
  annotation_logticks(scaled=F,
                      sides="l",
                      short=unit(0.05,"cm"),
                      mid=unit(0.1,"cm"),
                      long=unit(0.15,"cm"))+
  theme_bw()+
  theme(text=element_text(size=9),
        legend.title.align=0.2,
        legend.key.size=unit(0.4,"cm"),
        legend.margin=NULL,
        plot.title = element_text(hjust = 0.5,size=9),
        legend.key=element_blank(),
        panel.grid=element_blank(),
        legend.position="none",
        axis.ticks.y=element_blank())+
  annotate(geom="rect",
           ymin=1,
           ymax=c(Inoc_y/161,Ctrl_y/161),
           xmin=c(5.6,5.3),
           xmax=c(5.9,5.6),
           fill=c("darkgrey","white"),
           color="black")+
  annotate(geom="errorbar",
           x=c(5.75,5.45),
           ymin=c(Inoc_ymin/161,Ctrl_ymin/161),
           ymax=c(Inoc_ymax/161,Ctrl_ymax/161),
           col="black",
           width=0.1)+
  annotate(geom="text",
           x=c(5.3,5.1,5.6,2),
           y=c(Inoc_y/161+6,Ctrl_y/161+5,7,3),
           label=c(paste(round_any(Inoc_y,1),"+/-",round_any(Inoc_se,1)),
                   paste(round_any(Ctrl_y,1),"+/-",round_any(Ctrl_se,1)),
                   "***",
                   "Soil transfer ***"),
           col=c("black","grey50","black", "black"),
           size=c(2.5,2.5,4,3),
           hjust=0.5)+
  annotate("text",
           x=c(1,2,3,4,5),
           y=1,
           label=c("a","b","c","d","e"),
           size=2.75,
           vjust=-0.5)+
  expand_limits(x=c(0.4,5),y=c(1,30))+
  scale_x_discrete(expand = expand_scale(add=0.1))+
  ylab(yl_2a)+xlab("")
ggsave("Figures/Fig_2A.pdf",width=62,height=47,dpi=1000,unit="mm",device=cairo_pdf)
SD_fig2A<-res[,c('date','pot','trt','day','replica','CO2_rate','CO2_rate_interp','CO2_cumulative_interp')]
write.table(SD_fig2A,"SourceData/SourceData_Fig_2A.txt")

mean(map16s_wmet$CO2[25:27])/mean(map16s_wmet$CO2[28:30]) # This is the +38% cumulative CO2 production increase reported in text
t.test(map16s_wmet$CO2[25:27],map16s_wmet$CO2[28:30]) # Main text L.101

### 2b. Fig. 2B - TDC ----
# Plotting command
ggplot(map16s_wmet,aes(x=harvest,y=TDC,fill=Treatment,col="black"))+
  stat_summary(fun.data =  mean_se,
               position=position_dodge(0.6),
               width=0.6,
               geom="bar")+
  stat_summary(fun.data =  mean_se,
               position=position_dodge(0.6),
               width=0.2,
               geom="errorbar")+
  scale_color_manual(values=c("black","black"),name=NULL)+
  scale_fill_manual(values=c("white","darkgrey"),name=NULL)+
  theme_bw()+
  theme(panel.grid=element_blank(),
        text=element_text(size=9),
        legend.title.align=0.2,
        legend.key.size=unit(0.5,"cm"),
        plot.title = element_text(hjust = 0.5,size=9),
        legend.margin=NULL,
        legend.key=element_blank(),
        legend.position="none")+ 
  annotate(geom="text",
           x=c(2,3,4,5),
           y=c(450,450,450,450),
           label=c("**","***","***","***"),
           size=c(rep(5,4)))+
  annotate("text",
           x=c(1,2,3,4,5),
           y=c(-50,-50,-50,-50,-50),
           label=c("a","a","b","a","c"),
           size=2.75)+
  guides(fill=guide_legend(override.aes = list(col="black")),
         color=F)+
  ylim(-50,550)+ylab(" ")+xlab("")
ggsave("Figures/Fig_2B.pdf",width=62,height=48,dpi=1000,unit="mm")

### 2c. Fig. 2C - NH4 ----
ggplot(aes(x=harvest,
           y=NH4_N,
           fill=Treatment),
       data=map16s_wmet)+
  stat_summary(geom="bar",
               position=position_dodge(0.6),
               width=0.6,
               color="Black")+
  stat_summary(geom="errorbar",
               position=position_dodge(0.6),
               width=0.2,
               col="black")+
  scale_fill_manual(values=c("white","darkgrey"),name=NULL)+
  theme_bw()+
  theme(panel.grid=element_blank(),
        text=element_text(size=9),
        legend.key.size=unit(0.5,"cm"),
        legend.text.align=0,
        legend.margin=NULL,
        plot.title = element_text(hjust = 0.5,size=9),
        axis.title.y=element_text(margin=ggplot2::margin(r=9.5,"mm")),
        legend.key=element_blank(),
        legend.position="none")+ 
  annotate("text",
           x=c(5,1,2,3,4,5),
           y=c(150,-9,-9,-9,-9,-9),
           label=c("***","a","b","b","b","c"),
           size=c(5, 2.75, 2.75, 2.75, 2.75, 2.75))+
  ylim(-9,220)+
  ylab(yl_fig_2_bot)+xlab("Days since transfer")
ggsave("Figures/Fig_2C.pdf",width=64.5,height=48,unit="mm",dpi=1000)

### 2d. Fig. 2D - NO3 ----
ggplot(aes(x=droplevels(harvest),y=NO32,fill=Treatment),data=map16s_wmet)+
  stat_summary(geom="bar",
               position = position_nudge(0.15),
               width=0.3,
               color="black")+
  stat_summary(geom="errorbar",
               position=position_nudge(0.15),
               width=0.1)+
  scale_x_discrete(drop=F)+
  scale_fill_manual(values=c("white","darkgrey"),name=NULL,drop=F)+
  theme_bw()+
  theme(panel.grid=element_blank(),
        panel.background = NULL,
        plot.background = NULL,
        text=element_text(size=9),
        legend.key.size=unit(0.5,"cm"),
        legend.text.align=0,
        legend.margin=NULL,
        plot.title = element_text(hjust = 0.5,size=9),
        axis.title.y=element_text(margin=NULL),
        legend.key=element_blank(),
        legend.position="none")+ 
  annotate("text",
           x=c(2.15,3.15,4.15,5.15),
           y=c(-9,-9,-9,-9),
           label=c("a","b","c","d"),
           size=2.75)+
  ylim(-9,220)+
  ylab(" ")+xlab("Days since transfer")
ggsave("Figures/Fig_2D.pdf",width=60.5,height=48,unit="mm",dpi=1000)
SD_Fig2BCD<-map16s_wmet[,c('Treatment','replica','day','TDC','NO3_N','NH4_N')]
write.table(SD_Fig2BCD,"SourceData/SourceData_Fig_2BCD.txt")

#### 3. Figure 3: Nitrification functional genes (archaeal and bacterial amoA) qPCR data ----
qpcr_fig3<-subset(qpcr_NAs,variable!="16S (V3)")
ggplot(qpcr_fig3,aes(x=Harvest,y=value,color=Treatment))+
  stat_summary(position=position_dodge(0.3),size=0.3,aes(pch=as.factor(Harvest)))+
  geom_point(size=0.5,aes(pch=as.factor(Harvest)))+
  facet_wrap(~variable)+
  theme_bw()+
  theme(text=element_text(size=9),
        legend.title.align=0.2,
        legend.key.size=unit(0.4,"cm"),
        legend.margin=NULL,
        panel.grid.major.x= element_blank(),
        plot.title = element_text(hjust = 0.5,size=9),
        legend.key=element_blank(),
        strip.background = element_blank(),
        strip.text = element_blank(),
        legend.position = "NA")+
  scale_color_manual(values=c("grey70","grey20"),name=NULL)+
  scale_shape_manual(values=c("pre-"=17,
                              "1"=16,
                              "15"=16,
                              "30"=16,
                              "71"=16,
                              "161"=16))+
  scale_y_continuous(breaks=bks,minor_breaks=mbks)+
  coord_trans(y="log10")+
  geom_vline(xintercept=1.5)+
  geom_text(data=annot_amoA,aes(x=x,y=y,label=lab),colour="black",size=2.75)+
  xlab("Days since transfer")+
  ylab("Gene copies per g soil DW")
ggsave("Figures/Fig3.pdf",width=88,height=50,unit="mm",device=cairo_pdf)
write.table(qpcr[,c('Treatment','Harvest','X16S_DL','AOA_DL','AOB_DL')],"SourceData/SourceData_Fig3.txt")

# In the discussion related to Figure 3, we mention correlation tests between the relative abundance of 
# Nitrosomonadaceae or Nitrospira OTUs and the nitrate content of the soil
nitroso_otu<-t(subset(otutab, rownames(otutab) %in% rownames(deseqF)[grep("Nitrosom*", deseqF$taxonomy)]))
nitroso_matched<-nitroso_otu[match(map16s_wmet_wdna$SampleID,rownames(nitroso_otu)),]
all.equal(rownames(nitroso_matched),rownames(map16s_wmet_wdna))
nitrosp_otu<-t(subset(otutab, rownames(otutab) %in% rownames(deseqF)[grep("Nitrospi*", deseqF$taxonomy)]))
nitrosp_matched<-nitrosp_otu[match(map16s_wmet_wdna$SampleID,rownames(nitrosp_otu)),]
all.equal(rownames(nitrosp_matched),rownames(map16s_wmet_wdna))
nitromap<-data.frame(cbind(nitroso_matched,nitrosp_matched,NO3=map16s_wmet_wdna$NO3_N),Treatment=as.factor(map16s_wmet_wdna$Treatment),Harvest=map16s_wmet_wdna$Harvest)
nitromap$nitrosomonadaceae = rowSums(nitromap[,c(1:dim(nitroso_matched)[2])])
nitromap$nitrospira = rowSums(nitromap[,c((dim(nitroso_matched)[2]+1):(length(names(nitromap))-4))])
cor.test(nitromap$nitrospira,nitromap$NO3) # Correlation between Nitrospira OTUs and soil nitrate content
cor.test(nitromap$nitrosomonadaceae,nitromap$NO3) # Correlation between Nitrosomonadaceae OTUs and soil nitrate content



#### 4. Extended Data Figure 1 (Table): Initial soil chemistry comparisons ----
# Carbon %
C_pc_Yedo<-c(3.00,3.07,3.08)# Yedoma (this study)
C_pc_Transfer<-c(2.81,3.27,3.31)# Transferred soil (from Fontaine et al., 2007)

mean(C_pc_Yedo) # Mean for Yedoma
sd(C_pc_Yedo)/sqrt(2) # SE for Yedoma
mean(C_pc_Transfer) # Mean for Transferred soil
sd(C_pc_Transfer)/sqrt(2) # SE for Transferred soil

t.test(C_pc_Yedo, 
       C_pc_Transfer) # n.s.

# Nitrogen %
N_pc_Yedo<-c(0.239,0.248,0.245)# Yedoma (this study)
N_pc_Transfer<-c(0.289,0.335,0.337)# Transferred soil (from Fontaine et al., 2007)
mean(N_pc_Yedo) # Yedoma
sd(N_pc_Yedo)/sqrt(2) # Yedoma
mean(N_pc_Transfer) # Transferred soil
sd(N_pc_Transfer)/sqrt(2) # Transferred soil

t.test(N_pc_Yedo, 
       N_pc_Transfer) # *

# C:N ratio
CN_yedo<-C_pc_Yedo / N_pc_Yedo# Yedoma (this study)
CN_Transfer<-C_pc_Transfer / N_pc_Transfer# Transferred soil (from Fontaine et al., 2007)
mean(CN_yedo)
sd(CN_yedo)/sqrt(2)
mean(CN_Transfer)
sd(CN_Transfer)/sqrt(2)

t.test(CN_yedo,
       CN_Transfer) # ***

# TDC
TDC_yedo<-c(359.8,350.1,341) # Yedoma (this study)
TDC_Transfer<-c(49.2,56.1,12) # Transferred soil (this study)
mean(TDC_yedo)
sd(TDC_yedo)/sqrt(2)
mean(TDC_Transfer)
sd(TDC_Transfer)/sqrt(2)

t.test(TDC_yedo,
       TDC_Transfer) # ***

# DIN 
DIN_yedo<-c(172.83,179.5,177.98) # Yedoma (this study)
DIN_transfer<-c(133.54,118.37,128.13) # Transferred soil (this study)
mean(DIN_yedo)
sd(DIN_yedo)/sqrt(2)
mean(DIN_transfer)
sd(DIN_transfer)/sqrt(2)

t.test(DIN_yedo,
       DIN_transfer) # **

#### 5. Extended Data Figure 2: Effects of transfer on fungal communities ----
### 5a. Extended Data Figure 2a: Differential abundance (DESeq) of fungal OTUs ----
deseqFun$otu<-rownames(deseqFun)
psubFun_init<-filter(deseqFun,padj < 0.05)
rownames(psubFun_init)<-psubFun_init$otu
otutabf_for_mng$otu<-rownames(otutabf_for_mng)
otusubFun<-filter(otutabf_for_mng,otu %in% psubFun_init$otu)
psubFun<-filter(psubFun_init,otu %in% otusubFun$otu)
rownames(otusubFun)<-otusubFun$otu
rownames(psubFun)<-psubFun$otu
otusubFun<-otusubFun[match(rownames(psubFun),rownames(otusubFun)),]
all.equal(rownames(otusubFun),rownames(psubFun))
psubFun$ab_rar1000<-rowSums(otusubFun[,1:17])
psubFun$ab_rar1000_pc<-(psubFun$ab_rar1000/sum(otutabf[,1:17]))*100 ### abundance of the OTU in the total rarefied dataset in %
otusfull<-psubFun$taxonomy
taxa_names_clean<-gsub("c__","",
                       gsub(";.*","",
                            gsub("mycota;","mycota ",
                                 gsub("mycota;c__","mycota ",
                                      gsub("k__Bacteria;","",
                                           gsub("p__", "", 
                                                gsub("k__Fungi;","",
                                                     gsub("NA.*","Unidentified",
                                                          otusfull)
                                                     )
                                                )
                                           )
                                      )
                                 )
                            )
                       )
class_temp<-sub('^.','',as.factor(taxa_names_clean))
class<-recode(class_temp,
              'unidentified'="Undetermined fungi",
              'Unidentified'="Undetermined fungi",
              .default=levels(class_temp))
taxa<-as.factor(gsub("  "," ",class))
tax<-deseqFun[,7:8]
total_otuf<-filter(tax,otu %in% otutabf_for_mng$otu)
total_otuf$Phyla<-gsub("c__","",
                       gsub(";.*","",
                            gsub("mycota;","mycota ",
                                 gsub("mycota;c__","mycota ",
                                      gsub("k__Bacteria;","",
                                           gsub("p__", "", 
                                                gsub("k__Fungi;","",
                                                     gsub("NA.*","Unidentified",
                                                          total_otuf$taxonomy))))))))
total_otuf$Phyla_int<-as.factor(sub('^.','',as.factor(total_otuf$Phyla)))
total_otuf$Phyl2_int<-recode(as.factor(gsub("  "," ",total_otuf$Phyla_int)),
                             'unidentified'="Undetermined fungi",
                             'Unidentified'="Undetermined fungi",
                             "Ascomycota Unidentified"="Ascomycota unidentified",
                             "Basidiomycota Unidentified" ="Undetermined fungi", # One unidentified basidiomycete OTU might or might not be present, it is pooled with undetermined fungi for consistency with EDF1b
                             .default=levels(class_temp))
total_otuf2<-filter(total_otuf,total_otuf$Phyl2_int %in% levels(psubFun$Taxa))
total_otuf2$Taxa<-droplevels(total_otuf2$Phyl2_int)
a<-data.frame(total_otuf$Phyl2_int,otu = total_otuf$otu)
b<-left_join(psubFun,a,by="otu")
psubFun$Taxa<-droplevels(b$total_otuf.Phyl2_int)
psubFun$Taxa<-factor(psubFun$Taxa,levels=levels(psubFun$Taxa)[c(1:9,11,10)])
psubFun_final<-arrange(psubFun,desc(Taxa),(-log2FoldChange))
rownames(psubFun_final)<-c(1:length(rownames(psubFun_final))) 
psubFun_final$fact_abund<-ifelse(psubFun_final$ab_rar1000_pc>0.5, "High","Low")
levels(psubFun_final$Taxa)<-gsub("mycota",".",levels(psubFun_final$Taxa))
ggplot(psubFun_final,
       aes(x=as.numeric(rownames(psubFun_final)),
           y=-log2FoldChange))+
  theme_bw()+
  xlab(paste(length(psubFun_final$otu),"fungal OTUs affected by soil transfer\nDESeq2 NB-GLM Wald test"))+
  ylab(ds2b_yl)+
  geom_bar(aes(fill=Taxa),
           stat="identity",
           width=1)+
  scale_fill_manual(values=fung.pal)+
  theme(legend.position="none",
        legend.box.just="top",
        legend.justification=c(0,1),
        axis.text.y=element_blank(),
        axis.ticks.y=element_blank(),
        legend.key.size=unit(0.4,"cm"),
        text=element_text(size=10),
        panel.grid=element_blank(),
        panel.background=element_rect(fill="NA"))+
  geom_point(data=psubFun_final,
             aes(x=as.numeric(rownames(psubFun_final)),
                 y=0,
                 col=fact_abund),
             show.legend = F,
             pch=4)+
  scale_size(range=c(0.1,3),breaks=c(0,0.1,0.5,6,12,30))+
  scale_color_manual(values=c("black","NA"))+
  guides(color=F,
         size=guide_legend("Relative abundance (%)",
                           label.hjust = 1,
                           title.hjust = 0.5,
                           label.position = "right",
                           title.position = "top", 
                           order=1,
                           breaks=8,
                           override.aes=list(color=c("black",
                                                     "deepskyblue3",
                                                     "deepskyblue3",
                                                     "deepskyblue3",
                                                     "deepskyblue3")
                           )
         )
  )+
  coord_flip()
ggsave("Figures/EDF_2a.pdf",width=90,height=140,unit="mm",dpi=1000,device=cairo_pdf)

# In text we discuss the number of changing OTUs:
length(psubFun$baseMean)/length(deseqFun$baseMean)
# and which proportions of the total observations these OTUs represent:
sum(psubFun$ab_rar1000)/sum(otutabf_for_mng[,-18]) # value used in the article; normalized counts (rarefaction depth 5000)
sum(psubFun$baseMean)/sum(deseqFun$baseMean) # non-normalized counts, for information


### 5b. Extended Data Figure 2b: Fungal taxa summary ----
rownames(fun_tax)<-gsub(";.*","",
                        gsub("mycota;",". ",
                             gsub("mycota;c__",". ",
                                  gsub("k__Bacteria;","",
                                       gsub("p__", "", 
                                            gsub("k__Fungi;","",
                                                 rownames(fun_tax)))))))
tfun_tax<-as.data.frame(t(fun_tax))
all.equal(rownames(tfun_tax),rownames(mapits))
names(tfun_tax)
ordered_dat.F<-tfun_tax[,-which(names(tfun_tax) %in% c("unidentified","Other","Asco. Lecanoromycetes",
                                                       "Asco. Saccharomycetes","Basidio. unidentified",
                                                       "Basidio. Other","Basidio. Microbotryomycetes",
                                                       "Glomero. Glomeromycetes"))] # Removes Fungi:unidentified and Other
ordered_dat.F$'Undetermined fungi'<-tfun_tax$Other+tfun_tax$unidentified 
ordered_dat.F$'Other'<-(tfun_tax$`Asco. Lecanoromycetes`+
                          tfun_tax$`Asco. Saccharomycetes`+
                          tfun_tax$`Basidio. unidentified`+
                          tfun_tax$`Basidio. Other`+
                          tfun_tax$`Basidio. Microbotryomycetes`+
                          tfun_tax$`Glomero. Glomeromycetes`)
ordered_dat.F$Treatment=mapits$Treatment
ordered_dat.F$Days=mapits$harvest
ordered_dat.F.melt<-melt(ordered_dat.F,variable_name = "phyl_int",id.vars = c("Treatment","Days"))
ordered_dat.F.melt$phyl_int<-as.factor(gsub("mycota",".",
                                            recode(ordered_dat.F.melt$phyl_int,
                                                   "Asco. Other"="Ascomycota unidentified")))
ordered_dat.F.melt$phyl_int<-factor(ordered_dat.F.melt$phyl_int,levels=levels(ordered_dat.F.melt$phyl_int)[c(1:9,12,11,10)])
ggplot(ordered_dat.F.melt, aes(x = Days))+ theme_bw() +
  theme(legend.position="top")+ 
  facet_wrap(~Treatment)+
  scale_x_discrete(drop=F)+ 
  xlab("Days since transfer")+ylab("Relative abundance")+
  guides(fill=guide_legend("Phylum/class",
                           ncol=2,
                           title.position="top",
                           title.hjust = 0.5),
         lty=F)+
  geom_bar(aes(weight=value, fill = phyl_int),position = 'fill',width=0.7) + 
  scale_fill_manual(values=fung.pal)+
  geom_vline(aes(xintercept=1.5,lty=Treatment))+
  scale_linetype_manual(values=c(3,1))+
  theme(text=element_text(size=10),
        legend.key=element_blank(),
        panel.grid=element_blank(),
        legend.key.size=unit(4,"mm"),
        strip.background=element_rect(fill="grey90"))
ggsave("Figures/EDF_2b.pdf",width=85,height=90,unit="mm")

### 5c. Extended Data Figure 2c: fungal alpha diversity ----
alpha_its_div$Soil<-car::recode(paste(alpha_its_div$Treatment,alpha_its_div$harvest),'"Soil transfer Pre-"="Donor soil";else="Permafrost"')
alpha_its_div$Graph<-factor(droplevels(interaction(alpha_its_div$Soil,alpha_its_div$Treatment)),levels=levels(droplevels(interaction(alpha_its_div$Soil,alpha_its_div$Treatment)))[c(1,3,2)], labels=c("Control soil","Soil transfer","Donor soil"))
ggplot(alpha_its_div,
       aes(x=harvest,
           y=ace,
           col=Graph,
           pch=Graph))+
  stat_summary(size=0.3,
               position=position_dodge(0))+
  scale_color_manual(values=c("grey60","grey10","grey10"))+
  scale_shape_manual(values=c(16,16,17))+
  scale_x_discrete(drop=F)+
  ylim(0,NA)+
  guides(col=guide_legend("",
                          reverse = F,
                          direction="vertical"))+
  geom_vline(aes(xintercept=1.5),lty=1)+
  guides(col=guide_legend("",reverse = F,
                          override.aes = list(pch=c(16,16,17)),
                          labs=c("Control soil",
                                 "Soil transfer",
                                 "Donor soil")),
         pch=F)+
  theme(legend.key=element_blank(), 
        panel.background=element_rect(fill=NA,color="black"),
        panel.grid=element_blank(),
        text=element_text(size=10),
        legend.title.align=0.2,
        legend.margin=NULL,
        legend.key.size=unit(0.5,"cm"),
        legend.position=c(0.75,0.8),
        legend.background=element_blank())+ 
  xlab("Days since transfer")+ylab("Alpha diversity (ACE)")
ggsave("Figures/EDF_2c.pdf",width=95,height=50,unit="mm",device=cairo_pdf)

### 5d. Extended Data Figure 2d: Deseq fungi day 1 ----
total_otuf$Taxa<-recode(total_otuf$Phyl2_int, 
                        "Ascomycota Archaeorhizomycetes" = "Asco. Archaeorhizomycetes",
                        "Ascomycota Dothideomycetes" = "Asco. Dothideomycetes",
                        "Ascomycota Eurotiomycetes" = "Asco. Eurotiomycetes",
                        "Ascomycota Leotiomycetes" = "Asco. Leotiomycetes",
                        "Ascomycota Pezizomycetes" = "Asco. Pezizomycetes",
                        "Ascomycota Sordariomycetes" = "Asco. Sordariomycetes",
                        "Ascomycota unidentified" = "Asco. unidentified",
                        "Basidiomycota Agaricomycetes" = "Basidio. Agaricomycetes",
                        "Basidiomycota Tremellomycetes" = "Basidio. Tremellomycetes",
                        "Zygomycota Incertae_sedis" = "Zygo. Incertae_sedis",
                        .default="Undetermined fungi"
)
deseqFunH0$otu<-rownames(deseqFunH0)
deseqFunH0_int<-right_join(deseqFunH0,
                           total_otuf[,c(2,6)],
                           by="otu")
psubFunH0_init<-filter(deseqFunH0_int,
                       padj < 0.05)
rownames(psubFunH0_init)<-psubFunH0_init$otu
otutabf_for_mng$otu<-rownames(otutabf_for_mng)
otutabf_for_mng_H0<-otutabf_for_mng[,which(mapits_wmet$harvest=="1")]
otutabf_for_mng_H0$otu<-rownames(otutabf_for_mng_H0)
otusubFunH0<-filter(otutabf_for_mng_H0,
                    otu %in% psubFunH0_init$otu)
psubFunH0<-filter(psubFunH0_init,
                  otu %in% otusubFunH0$otu) 
rownames(otusubFunH0)<-otusubFunH0$otu
rownames(psubFunH0)<-psubFunH0$otu
otusubFunH0<-otusubFunH0[match(rownames(psubFunH0),rownames(otusubFunH0)),]
all.equal(rownames(otusubFunH0),rownames(psubFunH0))
psubFunH0$ab_rar1000<-rowSums(otusubFunH0[,1:6])
psubFunH0$ab_rar1000_pc<-(psubFunH0$ab_rar1000/sum(otutabf_for_mng_H0[,1:6]))*100 ### abundance of the OTU in the total rarefied dataset in %
psubFunH0$Taxa<-factor(psubFunH0$Taxa,
                       levels=levels(psubFunH0$Taxa)[c(1:3,5:11,4)])
psubFunH0_final<-arrange(psubFunH0,desc(Taxa),(-log2FoldChange))
rownames(psubFunH0_final)<-c(1:length(rownames(psubFunH0_final))) 
psubFunH0_final$fact_abund<-ifelse(psubFunH0_final$ab_rar1000_pc>0.5, "High","Low")

abotuFday1<-round_any(100*length(psubFunH0$otu)/length(which(rowSums(otutabf_for_mng_H0[,-7])!=0)),0.01)
abreadsFday1<-round_any(sum(psubFunH0_final$ab_rar1000_pc),0.01)

ggplot(psubFunH0_final,
       aes(x=as.numeric(rownames(psubFunH0_final)),
           y=-log2FoldChange))+
  theme_bw()+
  xlab(paste(length(psubFunH0_final$otu),"fungal OTUs affected by soil transfer\nDESeq2 NB-GLM Wald test"))+
  ylab(ds2b_yl)+
  geom_bar(aes(fill=Taxa),
           stat="identity",
           width=1)+
  scale_fill_manual(values=fung.pal)+ 
  theme(legend.position="none",
        legend.direction ="vertical",
        axis.text.y=element_blank(),
        axis.ticks.y=element_blank(),
        legend.key.size=unit(0.4,"cm"),
        text=element_text(size=10),
        panel.grid=element_blank(),
        panel.background=element_rect(fill="NA"))+
  geom_point(data=psubFunH0_final,
             aes(x=as.numeric(rownames(psubFunH0_final)),
                 y=0,
                 col=fact_abund),
             show.legend = F,
             pch=4)+
  scale_color_manual(values=c("black","NA"))+
  guides(color=F,
         fill=guide_legend("Phyla/Class"))+
  ylim(-6,13)+
  annotate("text",
           x=6,
           y=10,
           size=2.75,
           label=paste("Day 1\nOTUs: ",abotuFday1,"%\nReads: ",abreadsFday1,"%",sep = ""))+
  coord_flip()
ggsave("Figures/EDF_2d.pdf",width=90,height=80,unit="mm",dpi=1000,device=cairo_pdf)

### 5e. Extended Data Figure 2e: Deseq fungi day 161 ----
deseqFunH4$otu<-rownames(deseqFunH4)
deseqFunH4_int<-right_join(deseqFunH4,
                           total_otuf[,c(2,6)],
                           by="otu")
psubFunH4_init<-filter(deseqFunH4_int,
                       padj < 0.05)
rownames(psubFunH4_init)<-psubFunH4_init$otu
otutabf_for_mng$otu<-rownames(otutabf_for_mng)
otutabf_for_mng_H4<-otutabf_for_mng[,which(mapits_wmet$harvest=="161")]
otutabf_for_mng_H4$otu<-rownames(otutabf_for_mng_H4)
otusubFunH4<-filter(otutabf_for_mng_H4,
                    otu %in% psubFunH4_init$otu)
psubFunH4<-filter(psubFunH4_init,
                  otu %in% otusubFunH4$otu) 
rownames(otusubFunH4)<-otusubFunH4$otu
rownames(psubFunH4)<-psubFunH4$otu
otusubFunH4<-otusubFunH4[match(rownames(psubFunH4),rownames(otusubFunH4)),]
all.equal(rownames(otusubFunH4),rownames(psubFunH4))
psubFunH4$ab_rar1000<-rowSums(otusubFunH4[,1:6])
psubFunH4$ab_rar1000_pc<-(psubFunH4$ab_rar1000/sum(otutabf_for_mng_H4[,1:6]))*100 ### abundance of the OTU in the total rarefied dataset in %
psubFunH4$Taxa<-factor(psubFunH4$Taxa,
                       levels=levels(psubFunH4$Taxa)[c(1:3,5:11,4)])
psubFunH4_final<-arrange(psubFunH4,desc(Taxa),(-log2FoldChange))
rownames(psubFunH4_final)<-c(1:length(rownames(psubFunH4_final))) 
psubFunH4_final$fact_abund<-ifelse(psubFunH4_final$ab_rar1000_pc>0.5, "High","Low")
abotuFday161<-round_any(100*length(psubFunH4$otu)/length(which(rowSums(otutabf_for_mng_H4[,-7])!=0)),0.01)
abreadsFday161<-round_any(sum(psubFunH4_final$ab_rar1000_pc),0.01)

ggplot(psubFunH4_final,
       aes(x=as.numeric(rownames(psubFunH4_final)),
           y=-log2FoldChange))+
  theme_bw()+
  xlab(paste(length(psubFunH4_final$otu),"fungal OTUs affected by soil transfer\nDESeq2 NB-GLM Wald test"))+
  ylab(ds2b_yl)+
  geom_bar(aes(fill=Taxa),
           stat="identity",
           width=1)+
  scale_fill_manual(values=fung.pal)+
  theme(legend.position="none",
        legend.direction ="vertical",
        axis.text.y=element_blank(),
        axis.ticks.y=element_blank(),
        legend.key.size=unit(0.4,"cm"),
        text=element_text(size=10),
        panel.grid=element_blank(),
        panel.background=element_rect(fill="NA"))+
  geom_point(data=psubFunH4_final,
             aes(x=as.numeric(rownames(psubFunH4_final)),
                 y=0,
                 col=fact_abund),
             show.legend = F,
             pch=4)+
  scale_color_manual(values=c("black","NA"))+
  guides(color=F,
         fill=guide_legend("Phyla/Class"))+
  ylim(-6,13)+
  annotate("text",
           x=15,
           y=10,
           size=2.75,
           label=paste("Day 161\nOTUs: ",abotuFday161,"%\nReads: ",abreadsFday161,"%",sep = ""))+
  coord_flip()
ggsave("Figures/EDF_2e.pdf",width=90,height=140,unit="mm",dpi=1000,device=cairo_pdf)

### 5f. Extended Data Figure 2f: fungal alpha diversity response to rarefaction depth ----
trar_fun<-t(rarchao_fun)
trar2_fun<-subset(trar_fun,
                  rownames(trar_fun) %in% map16s$FungiXname)
mapits2<-subset(map16s,
                map16s$FungiXname %in% rownames(trar2_fun))
all.equal(rownames(trar2_fun),as.character(mapits2$FungiXname))
trar3_fun<-trar2_fun[match(as.character(mapits2$FungiXname),rownames(trar2_fun)),]
all.equal(rownames(trar3_fun),as.character(mapits2$FungiXname))
trar3_fun<-as.data.frame(trar3_fun)
rar4_fun<-as.data.frame(t(trar3_fun))
rar4_fun$rar_depth<-as.factor(gsub("*_./*.txt",
                                   "",
                                   gsub("alpha_rarefaction_",
                                        "",
                                        rownames(rar4_fun))))
rar5_fun<-aggregate(rar4_fun[,1:23], 
                    by = list(rar4_fun$rar_depth),
                    FUN=mean)
trar5_fun<-t(rar5_fun)
trar6_fun<-data.frame(trar5_fun[2:24,])
names(trar6_fun)<-trar5_fun[1,]
all.equal(as.character(mapits2$FungiXname),rownames(trar6_fun))
trar6_fun$Treatment<-mapits2$Treatment
trar6_fun$Harvest<-mapits2$Harvest
melted6_fun<-melt(trar6_fun,id.vars=c("Treatment","Harvest"))
melted6_fun$variable<-as.numeric(as.character(melted6_fun$variable))
melted6_fun$value<-as.numeric(as.character(melted6_fun$value))
levels(melted6_fun$Harvest)<-c("1","15","30","71","161","pre-")
ggplot(melted6_fun,
       aes(x=variable,
           y=value,
           col=Treatment,
           fill=Treatment,
           pch=Harvest))+
  annotate("point",
           x=1209,
           y=58.2,
           pch=17,
           col="grey60")+
  stat_smooth(data=subset(melted6_fun,variable>11),
              formula=y~log(x),
              method="lm",
              span=0.8,alpha=0.2,lwd=0.3,fullrange = 1)+
  stat_summary(fun.data=mean_se,lwd=0.2,position=position_dodge(100))+
  scale_color_manual(values=c("grey60","black"))+
  ylab("Chao1")+xlab("Rarefaction depth")+
  geom_vline(xintercept=c(11,30,1447,5700), # Read numbers of lowest-depth samples
             col="orange")+
  geom_vline(xintercept=5000, # Chosen rarefaction depth
             col="black")+
  guides(pch=guide_legend(title="Day"))+
  theme_bw()+
  annotate("text",
           x=c(700,4100,7200),
           y=250,
           label=c("Control\npre-incubation","Chosen\ndepth","Donor soil"),
           color=c("orange","black","orange"))+
  theme(panel.grid=element_blank())+
  scale_shape_manual(values=c(0,11,15,17,8,19))+
  scale_y_continuous(expand = c(0, 0), limits = c(0, 260)) 
ggsave("Figures/EDF_2f.pdf",width=180,height=140,unit="mm")



### 5g. Extended Data Figure 2g: Proportion of fungal OTUs affected or not by inoculation ----
otu_tab_ctrl_fun<-subset(otutabf,select=names(otutabf) %in% 
                           as.character(mapits_wmet$FungiXname[which(mapits_wmet$Treatment=="Control")]))
otu_tab_ctrl_fun<-otu_tab_ctrl_fun[-(which(rowSums(otu_tab_ctrl_fun)==0)),]

otu_tab_inoc_fun<-subset(otutabf,
                         select=colnames(otutabf) %in% 
                           as.character(mapits_wmet$FungiXname[which(mapits_wmet$Treatment=="Soil transfer")]))
otu_tab_inoc_fun<-otu_tab_inoc_fun[-(which(rowSums(otu_tab_inoc_fun)==0)),]

deseq_nochange_fun<-subset(deseqFun,pvalue>max(psubFun$pvalue))
otus_not_changing_c_fun<-rownames(otu_tab_ctrl_fun)[which(rownames(otu_tab_ctrl_fun) %in% rownames(deseq_nochange_fun))]

otus_not_changing_i_fun<-rownames(otu_tab_inoc_fun)[which(rownames(otu_tab_inoc_fun) %in% rownames(deseq_nochange_fun))]

total_inoc_changing_fun<-colSums(otu_tab_inoc_fun[which(rownames(otu_tab_inoc_fun) %in% psubFun$otu),])/5000
total_inoc_not_changing_pre_fun<-colSums(otu_tab_inoc_fun[which(rownames(otu_tab_inoc_fun) %in% rownames(deseq_nochange_fun)),])/5000

total_ctrl_changing_fun<-colSums(otu_tab_ctrl_fun[which(rownames(otu_tab_ctrl_fun) %in% psubFun$otu),])/5000
total_ctrl_not_changing_pre_fun<-colSums(otu_tab_ctrl_fun[which(rownames(otu_tab_ctrl_fun) %in% rownames(deseq_nochange_fun)),])/5000

otu_only_ctrl_fun<-otus_not_changing_c_fun[-which(otus_not_changing_c_fun %in% otus_not_changing_i_fun)]
total_only_ctrl_fun<-colSums(otu_tab_ctrl_fun[which(rownames(otu_tab_ctrl_fun) %in% otu_only_ctrl_fun),])/5000
total_ctrl_not_changing_fun<-total_ctrl_not_changing_pre_fun-total_only_ctrl_fun

otu_only_inoc_fun<-otus_not_changing_i_fun[-which(otus_not_changing_i_fun %in% otus_not_changing_c_fun)]
total_only_inoc_fun<-colSums(otu_tab_inoc_fun[which(rownames(otu_tab_inoc_fun) %in% otu_only_inoc_fun),])/5000
total_inoc_not_changing_fun<-total_inoc_not_changing_pre_fun-total_only_inoc_fun


ch_prop_fun<-data.frame(changing=c(total_ctrl_changing_fun,total_inoc_changing_fun),
                        not_changing=c(total_ctrl_not_changing_fun,total_inoc_not_changing_fun),
                        only=c(total_only_ctrl_fun,total_only_inoc_fun))
ch_prop_fun$FungiXname<-rownames(ch_prop_fun)
ch_fun<-left_join(ch_prop_fun,map16s_wmet[,c(10,5,6)],by='FungiXname')
meltch_fun<-melt(ch_fun)
meltch_fun$Harvest<-droplevels(meltch_fun$Harvest)
levels(meltch_fun$Harvest)<-c("1","15","161","30","71")
meltch_fun$Harvest<-factor(meltch_fun$Harvest,levels=levels(meltch_fun$Harvest)[c(1,2,4,5,3)])
names(meltch_fun)[4]<-"OTUs"
levels(meltch_fun$OTUs)<-c("Changing","Unaffected","Specific")
ggplot(meltch_fun,aes(x=Harvest))+
  geom_bar(aes(weight=value,
               fill=OTUs),
           position= 'fill')+
  xlab("Days since inoculation")+
  ylab("Relative abundance")+
  scale_x_discrete(drop=F)+
  scale_fill_brewer(type="qual",palette = 2)+
  facet_wrap(~Treatment)+
  theme_bw()+
  theme(panel.grid=element_blank())
ggsave("Figures/EDF_2g.pdf",width=12,height=8,unit="cm")

#### 6. Extended Data Figure 3 (Table): ANOVAs ----
# Because ANOVA is relatively robust to heteroscedasticty and non-normality of residuals in balanced designs, we decided to not be overly strict on violation of these assumptions in cases where residuals, quantile-quantile and scale-location plots looked fair
par(mfrow=c(2,2)) # easier to view lm diagnosis plots

lm_co2_rate<-lm(log(CO2_rate)~trt*as.factor(harvest),data=res)
plot(lm_co2_rate)
shapiro.test(resid(lm_co2_rate))
bartlett.test(log(res$CO2_rate),g=interaction(res$trt,res$harvest)) 
anova(lm_co2_rate)
lsmeans(lm_co2_rate,pairwise~trt)
1/exp(-0.3404424) # estimated increase in rates
1/exp(-0.3404424+(1.96*0.03988764)) # 95% CI lower
1/exp(-0.3404424-(1.96*0.03988764)) # 95% CI upper
lsmeans(lm_co2_rate,pairwise~as.factor(harvest),transform="resp")


lm_TDC<-lm(log(TDC)~Treatment*harvest,data=map16s_wmet)
plot(lm_TDC)
shapiro.test(resid(lm_TDC))
bartlett.test(log(map16s_wmet$TDC),g=interaction(map16s_wmet$Treatment,map16s_wmet$harvest))
anova(lm_TDC)
lsmeans(lm_TDC,pairwise~Treatment,transform="resp")
lsmeans(lm_TDC,pairwise~harvest,transform="resp")
lsmeans(lm_TDC,pairwise~Treatment:harvest,adjust="holm",transform="resp")

lm_DIN<-lm((DIN)~Treatment*harvest,data=map16s_wmet)
plot(lm_DIN)
shapiro.test(resid(lm_DIN))
bartlett.test(sqrt(map16s_wmet$DIN),g=interaction(map16s_wmet$Treatment,map16s_wmet$harvest))
kruskal.test(DIN~Treatment,data=map16s_wmet)
kruskal.test(DIN~harvest,data=map16s_wmet)
kruskal.test(DIN~interaction(Treatment:harvest),data=map16s_wmet)
dunn.test(map16s_wmet$DIN,g=interaction(map16s_wmet$Treatment:map16s_wmet$harvest),method="holm",list=T)

lm_NH4<-lm(log(NH4_N)~Treatment*harvest,data=map16s_wmet)
plot(lm_NH4)
shapiro.test(resid(lm_NH4))
bartlett.test(log(map16s_wmet$NH4_N),g=interaction(map16s_wmet$Treatment,map16s_wmet$harvest))
anova(lm_NH4)
lsmeans(lm_NH4,pairwise~Treatment,transform="res")
lsmeans(lm_NH4,pairwise~harvest,transform="res")
lsmeans(lm_NH4,pairwise~Treatment:harvest,transform="res")

mapno3<-subset(map16s_wmet,is.na(NO32)==F)
lm_no3<-lm(log(NO3_N)~harvest,data=mapno3)
plot(lm_no3)
shapiro.test(resid(lm_no3))
bartlett.test(log(mapno3$NO3_N),g=interaction(mapno3$Treatment,mapno3$harvest))
anova(lm_no3)
lsmeans(lm_no3,pairwise~harvest,adjust="holm",transform="res")

## Biomass proxies
lm_Cmic<-lm(log(Cmic_total)~Treatment*harvest,data=map16s_wmet)
plot(lm_Cmic)
shapiro.test(resid(lm_Cmic))
bartlett.test(log(map16s_wmet$Cmic_total),g=interaction(map16s_wmet$Treatment,map16s_wmet$harvest))
anova(lm_Cmic)
lsmeans(lm_Cmic,pairwise~harvest,adjust="holm",transform="res")

lm_totplfa<-lm(total~Treatment*Harvest,data=plin)
plot(lm_totplfa)
shapiro.test(resid(lm_totplfa))
bartlett.test(plin$total,g=interaction(plin$Treatment,plin$Harvest))
anova(lm_totplfa)
lsmeans(lm_totplfa,pairwise~Harvest,adjust="holm")


lm_bacplfa<-lm(log(all_bacteria)~Treatment*Harvest,data=plin)
plot(lm_bacplfa)
shapiro.test(resid(lm_bacplfa))
bartlett.test(log(plin$all_bacteria),g=interaction(plin$Treatment,plin$Harvest))
anova(lm_bacplfa)
lsmeans(lm_bacplfa,pairwise~Harvest,tranform="res")


lm_funplfa<-lm(all_fungi~Treatment*Harvest,data=plin)
plot(lm_funplfa)
shapiro.test(resid(lm_funplfa))
bartlett.test(plin$all_fungi,g=interaction(plin$Treatment,plin$Harvest))
anova(lm_funplfa)
lsmeans(lm_funplfa,pairwise~Harvest,adj="holm")
lsmeans(lm_funplfa,pairwise~Treatment)
lsmeans(lm_funplfa,pairwise~Harvest:Treatment,adjust="holm")

lm_proplfa<-lm(log(protozoa+1e-04)~Treatment*Harvest,data=plin)
shapiro.test(resid(lm_proplfa))
bartlett.test(log(plin$protozoa+1e-04),g=interaction(plin$Treatment,plin$Harvest))
anova(lm_proplfa)

lm_fbplfa<-lm(log(fungi_bacteria)~Treatment*Harvest,data=plin)
plot(lm_fbplfa)
shapiro.test(resid(lm_fbplfa))
bartlett.test(log(plin$fungi_bacteria),g=interaction(plin$Treatment,plin$Harvest))
anova(lm_fbplfa)
lsmeans(lm_fbplfa,pairwise~Harvest,ad="holm")
lsmeans(lm_fbplfa,pairwise~Treatment)
lsmeans(lm_fbplfa,pairwise~Treatment:Harvest,adjust="holm")


lm_alpha_bac<-lm(log(ace)~Treatment*Days,data=subset(alpha_16s_div,Days!="Pre-"))
shapiro.test(resid(lm_alpha_bac))
bartlett.test(sqrt(subset(alpha_16s_div,Days!="Pre-")$ace),g=interaction(subset(alpha_16s_div,Days!="Pre-")$Treatment,subset(alpha_16s_div,Days!="Pre-")$Days))
anova(lm_alpha_bac)
lsmeans(lm_alpha_bac,pairwise~Days,adj="holm",transform="res")

lm_alpha_fun<-lm(log(ace)~Treatment*harvest,data=subset(alpha_its_div,harvest!="Pre-"))
shapiro.test(resid(lm_alpha_fun))
bartlett.test(log(subset(alpha_its_div,harvest!="Pre-")$ace),g=interaction(subset(alpha_its_div,harvest!="Pre-")$Treatment,subset(alpha_its_div,harvest!="Pre-")$harvest))
anova(lm_alpha_fun)


anoqpcr<-subset(qpcr,Harvest!="pre-")
levels(anoqpcr$Treatment)<-c("C","I") # for readability in Dunn test output

X16Smod<-lm(log(X16S_DL)~Treatment*Harvest,data=anoqpcr)
plot(X16Smod)
shapiro.test(resid(X16Smod))
bartlett.test(log(anoqpcr$X16S_DL),interaction(anoqpcr$Treatment,anoqpcr$Harvest))
leveneTest(log(anoqpcr$X16S_DL),interaction(anoqpcr$Treatment,anoqpcr$Harvest))
anova(X16Smod)
lsmeans(X16Smod,pairwise~Treatment)
lsmeans(X16Smod,pairwise~Harvest,transform="resp")
lsmeans(X16Smod,pairwise~Treatment:Harvest,transform="resp",adjust="holm")

# qPCR: amoA functional genes

AOBmod<-lm(sqrt(AOB_DL)~Harvest,data=subset(qpcr,Harvest%in%c("15","30","71","161")))
plot(AOBmod)
shapiro.test(resid(AOBmod))
bartlett.test(log(subset(qpcr,Harvest%in%c("15","30","71","161"))$AOB_DL),subset(qpcr,Harvest%in%c("15","30","71","161"))$Harvest)
anova(AOBmod)
lsmeans(AOBmod,pairwise~Harvest,adj="holm")
dunn.test(subset(qpcr,Harvest%in%c("15","30","71","161"))$AOB_DL,subset(qpcr,Harvest%in%c("15","30","71","161"))$Harvest)

AOAmod<-lm((AOA_DL)~Harvest,data=subset(qpcr,Harvest!="pre-"))
plot(AOAmod)
shapiro.test(resid(AOAmod))
bartlett.test(anoqpcr$AOA_DL,anoqpcr$Harvest)
anova(AOAmod)

# Bacterial and fungal communities

totutabf<-data.frame(t(otutabf_for_mng[,-18]))
totutabf<-as.data.frame(lapply(FUN=round_any,totutabf,accuracy=1))
mvotuf<-mvabund(totutabf)
mapits_wmet$harvest<-droplevels(mapits_wmet$harvest)
mngf<-manyglm(mvotuf~mapits_wmet$Treatment*mapits_wmet$harvest,family="negative.binomial") # better fit with negative binomial than with poisson, cloglog or binomial
# anova.mng.fun<-anova(mngf,nBoot=999) # commented out to avoid running by mistake:takes a while
# anova.mng.fun

otutab_no_empty<-otutab_for_mng[-(which(rowSums(otutab_for_mng[,-30])==0)),-30]
totutab<-as.data.frame(lapply(FUN=round_any,data.frame(t(otutab_no_empty)),accuracy=1))
mvotu<-mvabund(totutab)
map16s_wmet_wdna$harvest2<-droplevels(map16s_wmet_wdna$harvest)
mngb<-manyglm(mvotu~map16s_wmet_wdna$Treatment*map16s_wmet_wdna$harvest2,family="negative.binomial") # better fit with negative binomial than with poisson, cloglog or binomial
# anova.mng.bac<-anova(mngb,nBoot = 999)# commented out to avoid running by mistake:takes a while
# anova.mng.bac



#### 7. Extended Data Figure 4: CO2 - TDC difference ----
cy<-subset(res,trt=="Control")
ci<-subset(res,trt=="Soil transfer")
ci$co2_i<-ci$co2
co<-cbind(cy,ci)
co$deltacod<-co$co2_i-co$co2

diy<-arrange(subset(map16s,trt=="Control"&harvest!="Pre-"),harvest)
dii<-arrange(subset(map16s,trt=="Soil transfer"&harvest!="Pre-"),harvest)
dii$TDC_i<-dii$TDC
dio<-cbind(diy,dii)
dio$deltacod<--(dio$TDC_i-dio$TDC)

dfanov<-data.frame(carbondif=c(co$deltacod,dio$deltacod),harvest=dio$harvest,variable=c(rep("CO2",15),rep("TDC",15)))
ggplot(dfanov,aes(x=harvest,y=carbondif,fill=variable,col="black"))+
  stat_summary(fun.data =  mean_se,
               position=position_dodge(0.6),
               width=0.6,
               geom="bar")+
  stat_summary(fun.data =  mean_se,
               position=position_dodge(0.6),
               width=0.2,
               geom="errorbar")+
  scale_color_manual(values=c("black","black"),name=NULL)+
  scale_fill_manual(values=c("grey60","grey30"),name=NULL,
                    labels=c('CO2'=expression(paste('CO'[2]*'-C difference')),
                             'TDC'= "TDC difference"))+
  theme_bw()+
  theme(panel.grid=element_blank(),
        text=element_text(size=9),
        legend.key.size=unit(0.5,"cm"),
        legend.text.align=0,
        legend.margin=NULL,
        plot.title=element_text(hjust=0.5,size=9),
        axis.title.y=element_text(margin=NULL),
        legend.key=element_blank(),
        legend.position=c(0.28,0.875))+ 
  guides(fill=guide_legend(override.aes = list(col="black")),
         color=F)+
  xlab("Days since transfer")+ylab(yl_edf2_top)
ggsave("Figures/EDF_4.pdf",width=65,height=68,dpi=1000,unit="mm")

#### 8. Extended Data Figure 5: Cmic, PLFA total, fungi:bacteria, bacteria, fungi, protozoa -----
### 8a. Extended Data Figure 5A - Cmic ----
map16s_wmet$harvest<-droplevels(map16s_wmet$harvest)
ggplot(map16s_wmet,aes(x=harvest,y=Cmic_total,fill=Treatment))+
  stat_summary(fun.data =  mean_se,position=position_dodge(0.6),width=0.6,geom="bar",col="black")+
  stat_summary(fun.data =  mean_se,position=position_dodge(0.6),width=0.2,geom="errorbar",col="black")+
  scale_fill_manual(values=c("white","darkgrey"),name="Microbes")+
  theme_bw()+
  scale_x_discrete(drop=F)+
  theme(panel.grid=element_blank(),
        text=element_text(size=9),
        legend.title.align=0.2,
        legend.key.size=unit(0.5,"cm"),
        plot.title=element_text(size=9,hjust=0.5,face="bold"),
        legend.key=element_blank(),
        legend.position="none")+ 
  annotate(geom="text",
           x=c(1,2,3,4,5),
           y=c(rep(-20,5)),
           label=c("a","b","ac","bc","bc"),
           size=2.75)+
  annotate(geom="text",
           x=4.5,
           y=630,
           label="Soil transfer n.s.\nTime ***",
           size=2.75)+
  ylab("mg-microbial-C per kg soil (dry weight)")+xlab("Days since transfer")
ggsave("Figures/EDF_5A.pdf",width=60,height=68,unit="mm",dpi=1000)

### 8b. Extended Data Figure 5B - Total PLFA ----
ggplot(plin,aes(x=Days,y=total,fill=Treatment))+
  stat_summary(fun.data =  mean_se,position=position_dodge(0.6),width=0.6,geom="bar",col="black")+
  stat_summary(fun.data =  mean_se,position=position_dodge(0.6),width=0.2,geom="errorbar",col="black")+
  scale_fill_manual(values=c("white","darkgrey"),name="Microbes")+
  theme_bw()+
  scale_x_discrete(drop=F)+
  theme(panel.grid=element_blank(),
        text=element_text(size=9),
        legend.title.align=0.2,
        legend.key.size=unit(0.5,"cm"),
        plot.title=element_text(size=9,hjust=0.5,face="bold"),
        legend.key=element_blank(),
        legend.position="none")+ 
  annotate(geom="text",
           x=c(1,3,5),
           y=c(-1,-1,-1),
           label=c("a","b","b"),
           size=2.75)+
  annotate(geom="text",
           x=4.5,
           y=22,
           label="Soil transfer n.s.\nTime ***",
           size=2.75)+
  ylab("nmol PLFA per g soil (dry weight)")+xlab("Days since transfer")
ggsave("Figures/EDF_5B.pdf",width=60,height=68,unit="mm",dpi=1000)

### 8c. Extended Data Figure 5C - Bacteria ----
ggplot(plin,aes(x=Days,y=all_bacteria,fill=Treatment))+
  stat_summary(fun.data =  mean_se,position=position_dodge(0.6),width=0.6,geom="bar",col="black")+
  stat_summary(fun.data =  mean_se,position=position_dodge(0.6),width=0.2,geom="errorbar",col="black")+
  scale_fill_manual(values=c("white","darkgrey"),name="Microbes")+
  theme_bw()+
  scale_x_discrete(drop=F)+
  theme(panel.grid=element_blank(),
        text=element_text(size=9),
        legend.title.align=0.2,
        plot.title=element_text(size=9,hjust=0.5,face="bold"),
        legend.key.size=unit(0.5,"cm"),
        legend.key=element_blank(),
        legend.position="none")+ 
  annotate(geom="text",
           x=c(1,3,5),
           y=c(-0.6,-0.6,-0.6),
           label=c("a","b","b"),
           size=2.75)+
  annotate(geom="text",
           x=4.5,
           y=13,
           label="Soil transfer n.s.\nTime ***",
           size=2.75)+
  ylab("nmol PLFA per g soil (dry weight)")+xlab("Days since transfer")
ggsave("Figures/EDF_5C.pdf",width=60,height=68,unit="mm",dpi=1000)


### 8d. Extended Data Figure 5D - Fungi ----
ggplot(plin,aes(x=Days,y=all_fungi,fill=Treatment))+
  stat_summary(fun.data =  mean_se,position=position_dodge(0.6),width=0.6,geom="bar",col="black")+
  stat_summary(fun.data =  mean_se,position=position_dodge(0.6),width=0.2,geom="errorbar",col="black")+
  scale_fill_manual(values=c("white","darkgrey"),name="Microbes")+
  theme_bw()+
  scale_x_discrete(drop=F)+
  theme(panel.grid=element_blank(),
        text=element_text(size=9),
        legend.title.align=0.2,
        legend.key.size=unit(0.5,"cm"),
        plot.title=element_text(size=9,hjust=0.5,face="bold"),
        legend.key=element_blank(),
        legend.position="none")+ 
  annotate(geom="text",
           x=c(1,3,5,3.02),
           y=c(-0.3,-0.3,-0.3,9.5),
           label=c("a","b","c","**"),
           size=c(rep(2.75,3),6))+
  annotate(geom="text",
           x=4.5,
           y=9,
           label="Soil transfer ***\nTime ***\nInteraction *",
           size=2.75)+
  ylim(c(-0.3,10))+
  ylab("nmol PLFA per g soil (dry weight)")+xlab("Days since transfer")
ggsave("Figures/EDF_5D.pdf",width=60,height=68,unit="mm",dpi=1000)


### 8e. Extended Data Figure 5E - Protozoa ----
ggplot(plin,aes(x=Days,y=protozoa,fill=Treatment))+
  stat_summary(fun.data =  mean_se,position=position_dodge(0.6),width=0.6,geom="bar",col="black")+
  stat_summary(fun.data =  mean_se,position=position_dodge(0.6),width=0.2,geom="errorbar",col="black")+
  scale_fill_manual(values=c("white","darkgrey"),name="Microbes")+
  theme_bw()+
  scale_x_discrete(drop=F)+
  theme(panel.grid=element_blank(),
        text=element_text(size=9),
        legend.title.align=0.2,
        plot.title=element_text(size=9,hjust=0.5,face="bold"),
        legend.key.size=unit(0.5,"cm"),
        legend.key=element_blank(),
        legend.position="none")+ 
  annotate(geom="text",
           x=4.5,
           y=0.3,
           label="n.s.",
           size=2.75)+
  ylab("nmol PLFA per g soil (dry weight)")+xlab("Days since transfer")
ggsave("Figures/EDF_5E.pdf",width=60,height=68,unit="mm",dpi=1000)


### 8f. Extended Data Figure 5F - fungi:bacteria ----
ggplot(plin,aes(x=Days,y=fungi_bacteria,fill=Treatment))+
  stat_summary(fun.data =  mean_se,position=position_dodge(0.6),width=0.6,geom="bar",col="black")+
  stat_summary(fun.data =  mean_se,position=position_dodge(0.6),width=0.2,geom="errorbar",col="black")+
  scale_fill_manual(values=c("white","darkgrey"),name=NULL)+
  theme_bw()+
  scale_x_discrete(drop=F)+
  theme(panel.grid=element_blank(),
        text=element_text(size=9),
        legend.title.align=0.2,
        legend.key.size=unit(0.5,"cm"),
        plot.title=element_text(size=9,hjust=0.5,face="bold"),
        legend.key=element_blank(),
        legend.margin = NULL,
        legend.position="none")+ 
  annotate(geom="text",
           x=c(1,3,5),
           y=c(-0.3,-0.3,-0.3),
           label=c("a","b","b"),
           size=c(2.75,2.75,2.75))+
  annotate(geom="text",
           x=4.5,
           y=6,
           label="Soil transfer **\nTime ***",
           size=2.75)+
  ylab("Ratio")+xlab("Days since transfer")
ggsave("Figures/EDF_5F.pdf",width=60,height=68,unit="mm",dpi=1000)

### 8g. Extended Data Figure 5G - 16S rRNA gene ----
ggplot(qpcr,aes(x=Harvest,y=X16S_DL,colour=Treatment,pch=Treatment))+
  stat_summary(position=position_dodge(0.3),fun.data=mean_se,size=0.2)+
  theme_bw()+
  theme(text=element_text(size=9),
        legend.title.align=0.2,
        legend.key.size=unit(0.4,"cm"),
        legend.margin=NULL,
        panel.grid.major.x= element_blank(),
        plot.title = element_text(hjust = 0.5,size=9),
        legend.key=element_blank(),
        strip.background = element_blank(),
        strip.text = element_blank(),
        legend.position = "NA")+
  scale_colour_manual(values=c("grey70","grey20"),name=NULL)+
  scale_y_continuous(breaks=bks,minor_breaks=mbks)+
  expand_limits(y=c(1e6,1e10))+
  coord_trans(y="log")+
  scale_y_log10(breaks=bks,minor_breaks=mbks)+
  annotate(geom="text",
           x=5.5,
           y=4e9,
           label="Soil transfer ***\nTime ***\nInteraction ***",
           size=2.75)+
  annotate(geom="text",
           x=c(2,3,4,5,6,3),
           y=c(rep(0.5e6,5),2e9),
           label=c("a","b","b","b","b","*"),
           size=c(rep(2.75,5),6))+
  geom_vline(xintercept=1.5)+
  xlab("Days since transfer")+
  ylab("Gene copies per g soil (dry weight)")
ggsave("Figures/EDF_5G.pdf",width=80,height=68,unit="mm",device=cairo_pdf)
t.test(qpcr$X16S_DL[c(7,11,13)],qpcr$X16S_DL[c(19,23,25)],var.equal=F)

#### 9. Extended Data Figure 6: Cumulative respiration of Inoculum soil and Permafrost+nutrients ----
resp161$Addition<-interaction(resp161$cellulose,resp161$nutrients)
levels(resp161$Addition)<-c("None","13C-cellulose","NPK","13C-cellulose + NPK")
resp161$Addition<-factor(resp161$Addition,levels=levels(resp161$Addition)[c(1,3,2,4)])
levels(resp161$soil_type)<-c("Transferred soil","Permafrost")
levels(resp161$trt)<-c("Inoculum + NPK","Permafrost","Permafrost + 13-C-cell","Permafrost + I + 13-C-cell",
                       "Permafrost + 13-C-cell + NPK","Permafrost + I + 13-C-cell + NPK",
                       "Permafrost + I","Permafrost + NPK","Permafrost + I + NPK")
meanT<-mean(resp161$CO2_cum_interp[which(resp161$trt=="Inoculum + NPK")])
seT<-sd(resp161$CO2_cum_interp[which(resp161$trt=="Inoculum + NPK")])/sqrt(2)
meanY<-mean(resp161$CO2_cum_interp[which(resp161$trt=="Permafrost")])
seY<-sd(resp161$CO2_cum_interp[which(resp161$trt=="Permafrost")])/sqrt(2)
mean_expected<-0.975*meanY+0.025*meanT*1.207 # 97.5 % Yedoma CO2-production + 2.5% Donor CO2-production * 1.207 to account for 20.7% higher CO2-production in Grassland soil without nutrient addition
se_expected<-0.975*seY+0.025*seT*1.207

mean_PE_exp<-1.089*0.975*meanY+0.025*meanT*1.207 # Expected values accounting for a 8.9% priming effect, as observed upon labile C addition
se_PE_exp<-1.089*0.975*seY+0.025*seT*1.207



estimate_df<-data.frame(x=c(0.33,0.2),
                        CO2_cum_interp=c(meanT,meanT*1.207),
                        ymax=c(meanT+seT,meanT*1.207+seT*1.207),
                        ymin=c(meanT-seT,meanT*1.207-seT*1.207),
                        inoc=c("Donor soil","Donor soil"),
                        Addition=c("NPK","None"))
resp_161_fig<-subset(resp161,soil_type=="Permafrost")
resp_161_fig$trt<-as.factor(resp_161_fig$trt)
levels(resp_161_fig$trt)<-c("Grassland + NPK","Control","13C-cellulose","13C-cellulose","13C-cellulose + NPK","13C-cellulose + NPK","Soil transfer","NPK","NPK")
resp_161_fig$trtfig<-factor(resp_161_fig$trt,levels=levels(resp_161_fig$trt)[c(2,5,3,6,4,1)])
levels(resp_161_fig$inoc) <-c("Permafrost","Permafrost + Soil transfer")
resp_161_fig$Addition<-factor(resp_161_fig$Addition,levels=levels(resp_161_fig$Addition)[c(1,3,2,4)])
ggplot(resp_161_fig,aes(x=inoc,y=CO2_cum_interp,fill=inoc,col=Addition))+
  stat_summary(geom="bar",position=position_dodge(0.54),
               width=0.5)+
  stat_summary(geom="errorbar",position=position_dodge(0.54),
               width=0.1)+
  theme_bw()+
  scale_fill_manual(values=c("grey90","white","darkgrey","grey"))+
  scale_color_manual(values=c("None"="black",
                              "Soil transfer"="black",
                              "13C-cellulose"="#377eb8",
                              "NPK"="#e41a1c",
                              "13C-cellulose + NPK"="#984ea3"))+
  guides(lty=guide_legend("Data source", override.aes=list(fill=c(NA,"white"),color="black",lty=c(3,1))),
         fill=guide_legend("Soil", override.aes=list(color="black")),
         col=guide_legend("Chemical addition", override.aes = list(fill="white",lty=1)))+
  scale_linetype_manual(values=c(3,1))+
  theme(text=element_text(size=9),
        legend.title.align=0,
        legend.key.size=unit(0.4,"cm"),
        legend.margin=NULL,
        panel.grid = element_blank(),
        plot.title = element_text(hjust = 0.5,size=10),
        axis.text.x = element_text(face="bold",color="grey20"))+
  ylim(0,1200)+
  geom_bar(stat="identity",
           aes(x=x,
               color=Addition,
               lty=c("Measured","Estimated")),
           width=0.125,
           data=estimate_df)+
  geom_errorbar(aes(x=x,ymax=ymax,
                    ymin=ymin,
                    color=Addition),
                data=estimate_df,
                width=0.02)+
  annotate("text",
           x=0.1,
           y=c(1175,
               1100,
               1050,
               1000,
               950),
           label=c(EDF5_anova_header,
                   EDF5_anova_inoc,
                   EDF5_anova_cell,
                   EDF5_anova_nutr,
                   EDF5_anova_inter),
           hjust="left",
           size=2.75)+
  annotate("pointrange",
           x=1.8,
           y=mean_expected,
           ymin=mean_expected-se_expected,
           ymax=mean_expected+se_expected,
           col="darkgreen",
           pch="+",
           size=0.75)+
  annotate("rect",
           xmin=-Inf,
           ymin=-Inf,
           xmax=0.5,
           ymax=450,
           fill=NA,
           col="black",
           lwd=0.3)+
  annotate("text",
           x=0.1,
           y=400,
           label="Donor soil",
           fontface="bold",
           size=2.5,
           hjust="left",
           col="grey20")+
  ylab(yl_edf_5_top)+
  expand_limits(x=c(0))+
  xlab(NULL)
ggsave("Figures/EDF_6.pdf",width=150,height=100,dpi=1000,unit="mm",device=cairo_pdf)


#### 10. Extended Data Figure 7 (Table): Variable selection using RandomForests ----

all.equal(rownames(ordered_dat),as.character(map16s$SampleID[-2]))
ttax2$SampleID<-rownames(ttax2)
ttax2_forest<-ttax2[which(rownames(ttax2)%in%map16s_wmet_wdna$SampleID),]
rfmap_pre<-left_join(ttax2_forest,map16s_wmet_wdna,by="SampleID")
rfmap<-left_join(rfmap_pre,qpcr,by="ID_unique_extraction")
rownames(rfmap)<-rfmap$SampleID
alpha_16s_div_int<-alpha_16s_div[which(rownames(alpha_16s_div)%in%rownames(rfmap)),]
all.equal(rownames(rfmap),rownames(alpha_16s_div_int))
rfmap$Alpha_div<-alpha_16s_div_int$ace
rfmap$AOB<-car::recode(rfmap$AOB_DL,'NA=0')
rfmap$AOA<-car::recode(rfmap$AOA_DL,'NA=0')
var_to_keep<-c("Other","AD3","Acidobacteria","Actinobacteria","Armatimonadetes","BRC1","Bacteroidetes",
               "Chlamydiae","Chlorobi","Chloroflexi","Cyanobacteria","Elusimicrobia","FBP","FCPU426",
               "Fibrobacteres","Firmicutes","GN02","Gemmatimonadetes","MVP-21","Nitrospirae","OD1","OP11",
               "OP3","Planctomycetes","Spirochaetes","TM6","TM7","Tenericutes","Verrucomicrobia","WPS-2","WS2",
               "WS3","WS4","WS5","Alphaproteobacteria","Betaproteobacteria","Deltaproteobacteria","Gammaproteobacteria",
               "SampleID",
               "TDC","Cmic_total","NO3_N","NH4_N","DIN",
               "X16S_DL","AOA","AOB",
               "Alpha_div")
rfmap<-subset(rfmap,select=var_to_keep)
rfmap<-left_join(rfmap,res[,which(names(res) %in% c("CO2_rate_detrended","SampleID"))],by="SampleID")
rfvsurf<-rfmap[,-which(names(rfmap) %in% c("CO2_rate_detrended","SampleID"))]
forest_full<-VSURF(rfvsurf,
                   rfmap$CO2_rate_detrended,
                   nfor.thres=2000,
                   nfor.interp=25,
                   nfor.pred=1000,
                   scaled=T)
forest_full
EDT3<-data.frame(Variable=names(rfvsurf)[forest_full$imp.mean.dec.ind],
                 Importance=forest_full$imp.mean.dec,
                 SD_imp=forest_full$imp.sd.dec,
                 err.interp=c(forest_full$err.interp,rep(NA,length(forest_full$imp.mean.dec)-length(forest_full$err.interp))),
                 err.pred=c(forest_full$err.pred,rep(NA,length(forest_full$imp.mean.dec)-length(forest_full$err.pred))))
write.table(EDT3,"Figures/EDT3.txt")

#### 11. Extended Data Figure 8: Reproduced incubation data ----
#### 11a. Extended Data Figure 8a: Yedoma with active layer inocula ----
edf8y<-lm(Cum_mgC_per_gDW_final~Treatment,data=subset(EDF8,Soil_type=="Yedoma"))
shapiro.test(residuals(edf8y))
bartlett.test(subset(EDF8,Soil_type=="Yedoma")$Cum_mgC_per_gDW_final,g = subset(EDF8,Soil_type=="Yedoma")$Treatment)
anova(edf8y)
lsmeans(edf8y,pairwise~Treatment,adjust="holm")

ggplot(subset(EDF8,Soil_type=="Yedoma"),aes(y=Cum_mgC_per_gDW_final*1000,x=Treatment,fill=Treatment))+
  stat_summary(geom="bar",width=0.3,color="black")+
  stat_summary(geom="errorbar",width=0.1,color="black")+
  geom_text(aes(x=x,y=y,label=labs),data=posthoc389df_yedo,vjust=0.5)+
  scale_color_manual(values=c("NA","#E41A1C", "#377EB8", "#4DAF4A","darkgrey"))+
  scale_fill_manual(values=c("white","#E41A1C", "#377EB8", "#4DAF4A","darkgrey"))+
  theme_bw()+
  theme(panel.spacing = unit(0,"cm"),
        axis.line.y=element_line(),
        strip.background = element_blank(),
        axis.text.x=element_blank())+
  facet_grid(~Soil_type,scales="free_x",
             space="free_x",
             switch="x",
             margin=F)+
  stat_summary(geom="crossbar",
               aes(y=DOC_inoc_gDW*1000,
                   color=Treatment),
               position=position_nudge(0.3),
               width=0.2,
               show.legend=F)+
  guides(color=guide_legend(""),
         fill=guide_legend(""))+
  ylab(ylab389)+xlab("")+
  annotate("text",
           x=1,
           y=1400,
           size=3,
           label="OMC%\n6.64 +/- 0.05")+
  theme(axis.text.x=element_blank(),
        axis.ticks.x=element_blank(),
        panel.grid=element_blank())
ggsave("Figures/EDF8a.pdf",width=180,height=100,unit="mm")

#### 11b. Extended Data Figure 8b: Holocene permafrost ----
t.test(subset(EDF8,Soil_type=="Permafrost1")$Cum_mgC_per_gDW_final[1:4],subset(EDF8,Soil_type=="Permafrost1")$Cum_mgC_per_gDW_final[5:8],alternative = "less")
t.test(subset(EDF8,Soil_type=="Permafrost2")$Cum_mgC_per_gDW_final[1:4],subset(EDF8,Soil_type=="Permafrost2")$Cum_mgC_per_gDW_final[5:8],alternative = "less")
t.test(subset(EDF8,Soil_type=="Permafrost3")$Cum_mgC_per_gDW_final[1:4],subset(EDF8,Soil_type=="Permafrost3")$Cum_mgC_per_gDW_final[5:8],alternative = "less")

ggplot(subset(EDF8,Soil_type!="Yedoma"),
       aes(y=Cum_mgC_per_gDW_final*1000,
           x=Treatment,
           fill=Treatment))+
  stat_summary(geom="bar",
               width=0.4,
               color="black")+
  stat_summary(geom="errorbar",
               width=0.1,
               color="black")+
  geom_text(aes(x=x,
                y=y*1000,
                label=labs,
                fontface=face),
            data=posthoc389df_pf,
            vjust=0.5,
            size=3)+
  scale_color_manual(values=c("NA","darkgrey"))+
  scale_fill_manual(values=c("white","darkgrey"))+
  theme_bw()+
  theme(panel.spacing = unit(0.1,"cm"),
        axis.line.y=element_line(),
        strip.background = element_blank())+
  facet_wrap(~Soil_type,
             scales="free",
             switch="x")+
  stat_summary(geom="crossbar",
               aes(y=DOC_inoc_gDW*1000,
                   color=Treatment),
               position=position_nudge(0.3),
               width=0.2,
               show.legend=F)+
  guides(color=guide_legend(""),
         fill=guide_legend(""))+
  ylab(ylab389)+xlab(NULL)+
  theme(axis.text.x=element_blank(),
        axis.ticks.x=element_blank(),
        panel.grid=element_blank())
ggsave("Figures/EDF8b.pdf",width=180,height=100,unit="mm")



#### 11c. Extended Data Figure 8 - supplement: Initial pH reproduced incubation ----
# We mention in Methods that inoculation did not affect the pH of the soils one day after inoculation in the reproduced experiment presented in Extended Data Figure 5
m2<-data.frame(pH=c(6.85, # pH values for the jars harvested one day after inoculation in the reproduced incubation
                    6.68,
                    6.86,
                    6.83,
                    7.27,
                    7.32,
                    7.38,
                    7.27,
                    6.65,
                    7.43,
                    7.43,
                    7.47,
                    7.35,
                    7.44,
                    7.28,
                    6.76,
                    7.42,
                    6.66,
                    7.39,
                    7.18),
               treatment=c(rep("Ctrl",4),rep("IceCut",4),rep("Cryo",4),rep("Peat",4),rep("Theix",4)))
phm2<-lm((pH)~treatment, data=m2)
par(mfrow=c(2,2))
plot(phm2)
shapiro.test(resid(phm2)) # Non-normal distribution, ANOVA results should be considered with caution
hist(resid(phm2))
par(mfrow=c(1,1))
anova(phm2) # No significant differences between treatments
kruskal.test(m2$pH,m2$treatment) # No significant differences between treatments


#### 12. Extended Data Figure 9: Respiration rates ----
res_interp<-subset(res_full,trt %in% c("Y_F","Y_0"))
res_interp$set<-car::recode(res_interp$pot,"c(124,125,126,127,128,129)='A';else='B'")

pwresmod<-lm(log(CO2_rate)~trt*as.factor(day),data=res_interp)
plot(pwresmod)
shapiro.test(resid(pwresmod))
pwdf<-data.frame(lsmeans(pwresmod,pairwise~trt*as.factor(day),adjust="none")$contrasts)
pwdf$p.holm.231<-p.adjust(pwdf$p.value,method="holm")
pwdf_orthogonal<-pwdf[c(1,42,79,112,141,166,187,204,217,226,231),]
pwdf_orthogonal$p.adj.holm<-p.adjust(pwdf_orthogonal$p.value,method="holm")

ggplot(res_interp,aes(x=day,y=CO2_rate_interp,color=trt,fill=trt))+
  stat_summary(fun.data =  mean_se,
               size=0.4,
               geom="pointrange",
               aes(y=CO2_rate,x=day,alpha=set),pch=4)+
  stat_summary(fun.data =  mean_se,
               size=0.4,
               geom="pointrange",
               aes(pch=set))+
  scale_color_manual(values=c("grey70","grey20","blue","red"),name=NULL)+
  theme_bw()+
  scale_y_log10(breaks=c(1,5,10,20,30,50))+
  annotation_logticks(side="l")+
  theme(text=element_text(size=9),
        legend.title.align=0.2,
        legend.key.size=unit(0.4,"cm"),
        legend.margin=NULL,
        panel.grid =  element_blank(),
        plot.title = element_text(hjust = 0.5,size=9),
        legend.key=element_blank(),
        legend.position="none",
        axis.ticks.y=element_blank())+
  annotate(geom = "text",
           x=c(2,15,30,71,161),
           y=c(13,22,13,8,3),
           label=c("2","15","30","71","161"),
           size=3,
           col="red")+
  annotate(geom="text",
           x=c(2,15,21,30,107,141,161),
           y=c(11,9,5.5,5,2,1.4,1.4),
           label=c("***","***","***","***","**","***","***"),
           size=4,
           fontface="bold")+
  scale_alpha_manual(values=c(0,1))+
  ylab(yl_edf9_top2)+xlab("Days since transfer")
ggsave("Figures/EDF_9.pdf",width=135,height=105,dpi=1000,unit="mm",device=cairo_pdf)


#### 13. Extended Data Figure 10: Effects of transfer on bacterial communities ----
### 13a. Extended Data Figure 10a alpha rarefaction bacteria ----
trar<-t(rarchao)
trar2<-subset(trar,rownames(trar) %in% map16s$SampleID)
all.equal(rownames(trar2),as.character(map16s$SampleID))
trar3<-trar2[match(as.character(map16s$SampleID),rownames(trar2)),]
all.equal(rownames(trar3),as.character(map16s$SampleID))
trar3<-as.data.frame(trar3)
rar4<-as.data.frame(t(trar3))
rar4$rar_depth<-as.factor(gsub("*_./*.txt","",gsub("alpha_rarefaction_","",rownames(rar4))))
rar5<-aggregate(rar4[,1:36], by = list(rar4$rar_depth),FUN=mean)
trar5<-t(rar5)
trar6<-data.frame(trar5[2:37,])
names(trar6)<-trar5[1,]
all.equal(as.character(map16s$SampleID),rownames(trar6))
trar6$Treatment<-map16s$Treatment
trar6$Harvest<-map16s$Harvest
melted6<-melt(trar6,id.vars=c("Treatment","Harvest"))
melted6$variable<-as.numeric(as.character(melted6$variable))
melted6$value<-as.numeric(as.character(melted6$value))
levels(melted6$Harvest)<-c("1","15","30","71","161","pre-")
ggplot(melted6,aes(x=variable,y=value,col=Treatment,fill=Treatment,pch=Harvest))+
  stat_smooth(data=subset(melted6,variable>11),
              formula=y~log(x),
              method="lm",
              span=0.8,alpha=0.2,lwd=0.3,fullrange = 1)+
  stat_summary(fun.data=mean_se,lwd=0.2,position=position_dodge(100))+
  scale_color_manual(values=c("grey60","black"))+
  ylab("Chao1")+xlab("Rarefaction depth")+
  geom_vline(xintercept=1407,col="orange")+ # Lowest sample
  geom_vline(xintercept=5697,col="orange")+ # 2nd-lowest sample
  geom_vline(xintercept=5000,col="black")+ # rarefaction depth
  guides(pch=guide_legend(title="Day"))+
  theme_bw()+
  annotate("text",
           x=c(600,4200,7200),
           y=2500,
           label=c("Soil transfer\nday 1","Chosen\ndepth","Control\npre-incubation"),
           color=c("orange","black","orange"))+
  theme(panel.grid=element_blank())+
  scale_shape_manual(values=c(0,11,15,17,8,19))+
  scale_y_continuous(expand = c(0, 0), limits = c(0, 2700)) 
ggsave("Figures/EDF_10a.pdf",width=180,height=140,unit="mm",device=cairo_pdf)

### 13b. Extended Data Figure 10b: Deseq bacteria day 1 ----
otusfull16s<-deseqH0$taxonomy
phyl_namesfull16s <- clean_otu_taxonomy_proteo(otusfull16s)
deseqH0$phyla_temp<-recode(as.factor(phyl_namesfull16s),
                           "Acidobacteria"="Acidobacteria",
                           "Actinobacteria"="Actinobacteria",
                           "Bacteroidetes"="Bacteroidetes",
                           "Chloroflexi"="Chloroflexi",
                           "Firmicutes"="Firmicutes",
                           "Gemmatimonadetes"="Gemmatimonadetes",
                           "Nitrospirae"="Nitrospirae",
                           "Alphaproteobacteria"="Alphaproteobacteria",
                           "Betaproteobacteria"="Betaproteobacteria",
                           "Gammaproteobacteria"="Gammaproteobacteria",
                           "Deltaproteobacteria"="Deltaproteobacteria",
                           "Verrucomicrobia"="Verrucomicrobia",
                           .default="Other")
deseqH0$Phyla<-factor(deseqH0$phyla_temp,
                      levels=c("Acidobacteria",
                               "Actinobacteria",
                               "Bacteroidetes",
                               "Chloroflexi",
                               "Firmicutes",
                               "Gemmatimonadetes",
                               "Nitrospirae",
                               "Alphaproteobacteria",
                               "Betaproteobacteria",
                               "Gammaproteobacteria",
                               "Deltaproteobacteria",
                               "Verrucomicrobia", 
                               "Other" )
)

deseqH0$otu<-rownames(deseqH0)
psubFH0_init<-filter(deseqH0,
                     padj < 0.05)
rownames(psubFH0_init)<-psubFH0_init$otu
## filter otu table to keep only relevant harvest
otutab_for_mng_H0<-otutab_for_mng[,which(map16s_wmet_wdna$harvest=="1")]
otutab_for_mng_H0$otu<-rownames(otutab_for_mng_H0)
otusubF_H0<-filter(otutab_for_mng_H0,
                   otu %in% psubFH0_init$otu)
psubFH0<-filter(psubFH0_init,
                otu %in% otusubF_H0$otu) 
rownames(otusubF_H0)<-otusubF_H0$otu
rownames(psubFH0)<-psubFH0$otu
otusubF_H0<-otusubF_H0[match(rownames(psubFH0),
                             rownames(otusubF_H0)),]
all.equal(rownames(otusubF_H0),rownames(psubFH0))
psubFH0$ab_rar1000<-rowSums(otusubF_H0[,1:5])
psubFH0$ab_rar1000_pc<-(psubFH0$ab_rar1000/sum(otutab_for_mng_H0[,1:5]))*100 ### abundance of the OTU in the total rarefied dataset in %

# Rearrange the dataset by decreasing Phyla and Fold-change for readability
psubFH0_final<-arrange(psubFH0,desc(Phyla),
                       (-log2FoldChange))
rownames(psubFH0_final)<-c(1:length(rownames(psubFH0_final))) 
psubFH0_final$fact_abund<-ifelse(psubFH0_final$ab_rar1000_pc>0.5,
                                 "High",
                                 "Low")
psubFH0_final$fact_abund2<-ifelse(rownames(psubFH0_final) %in% grep("*Nitro*",psubFH0_final$taxonomy),
                                  "Nitrifier", 
                                  psubFH0_final$fact_abund)
abotuBday1<-round_any(length(psubFH0$otu)/length(which(rowSums(otutab_for_mng_H0[,-6])!=0)),0.001)
abreadsBday1<-round_any(sum(psubFH0_final$ab_rar1000_pc),0.01)

ggplot(psubFH0_final,
       aes(x=as.numeric(rownames(psubFH0_final)),
           y=-log2FoldChange))+
  theme_bw()+
  xlab(paste(length(psubFH0_final$otu),"bacterial OTUs affected by soil transfer\n DESeq2 NB-GLM Wald test"))+
  ylab(ds2b_yl)+
  geom_bar(aes(fill=Phyla),
           stat="identity",
           width=1)+
  scale_fill_manual(values=phyla.pal,drop=F)+
  theme(legend.position="bottom",
        legend.box="vertical",
        axis.text.y=element_blank(),
        axis.ticks.y=element_blank(),
        legend.key.size=unit(0.4,"cm"),
        text=element_text(size=10),
        panel.grid=element_blank(),
        panel.background=element_rect(fill="NA")
  )+
  guides(color=F,
         alpha=F,
         fill = guide_legend("Phylum/class",
                             override.aes = list(color=NA),
                             ncol=1,
                             order=2,
                             title.position="top"))+
  ylim(-13,13)+
  annotate("text",x=3,y=-7,size=2.75,label=paste("Day 1\nOTUs: ",abotuBday1,"%\nReads: ",abreadsBday1,"%",sep = ""))+
  coord_flip()
ggsave("Figures/EDF_10b.pdf",width=70,height=110,unit="mm",device=cairo_pdf)


### 13c. Extended Data Figure 10c: Deseq bacteria day 15 ----
deseqH1$otu<-rownames(deseqH1)
deseqH1_int<-right_join(deseqH1,deseqH0[,9:10],by="otu")
psubFH1_init<-filter(deseqH1_int,
                     padj < 0.05)
rownames(psubFH1_init)<-psubFH1_init$otu
## filter otu table to keep only relevant harvest
otutab_for_mng_H1<-otutab_for_mng[,which(map16s_wmet_wdna$harvest=="15")]
otutab_for_mng_H1$otu<-rownames(otutab_for_mng_H1)
otusubF_H1<-filter(otutab_for_mng_H1,
                   otu %in% psubFH1_init$otu)
psubFH1<-filter(psubFH1_init,
                otu %in% otusubF_H1$otu) 
rownames(otusubF_H1)<-otusubF_H1$otu
rownames(psubFH1)<-psubFH1$otu
otusubF_H1<-otusubF_H1[match(rownames(psubFH1),
                             rownames(otusubF_H1)),]
all.equal(rownames(otusubF_H1),rownames(psubFH1))
psubFH1$ab_rar1000<-rowSums(otusubF_H1[,1:6])
psubFH1$ab_rar1000_pc<-(psubFH1$ab_rar1000/sum(otutab_for_mng_H1[,1:6]))*100 ### abundance of the OTU in the total rarefied dataset in %

psubFH1_final<-arrange(psubFH1,desc(Phyla),
                       (-log2FoldChange))
rownames(psubFH1_final)<-c(1:length(rownames(psubFH1_final)))
psubFH1_final$fact_abund<-ifelse(psubFH1_final$ab_rar1000_pc>0.5,
                                 "High",
                                 "Low")
psubFH1_final$fact_abund2<-ifelse(rownames(psubFH1_final) %in% grep("*Nitro*",psubFH1_final$taxonomy),
                                  "Nitrifier", 
                                  psubFH1_final$fact_abund)
abotuBday15<-round_any(100*length(psubFH1$otu)/length(which(rowSums(otutab_for_mng_H1[,-7])!=0)),0.01)
abreadsBday15<-round_any(sum(psubFH1_final$ab_rar1000_pc),0.01)
ggplot(psubFH1_final,
       aes(x=as.numeric(rownames(psubFH1_final)),
           y=-log2FoldChange))+
  theme_bw()+
  xlab(paste(length(psubFH1_final$otu),"bacterial OTUs affected by soil transfer"))+
  ylab(ds2b_yl)+
  geom_bar(aes(fill=Phyla),
           stat="identity",
           width=1)+
  scale_fill_manual(values=phyla.pal)+
theme(legend.position="bottom",
      legend.box="vertical",
      axis.text.y=element_blank(),
      axis.ticks.y=element_blank(),
      legend.key.size=unit(0.4,"cm"),
      text=element_text(size=10),
      panel.grid=element_blank(),
      panel.background=element_rect(fill="NA")
)+
  geom_segment(data=psubFH1_final,
               aes(x=as.numeric(rownames(psubFH1_final)),
                   xend=as.numeric(rownames(psubFH1_final)),
                   y=-1.5,
                   yend=0,
                   alpha=fact_abund2),
               arrow=arrow(type = "closed",
                           length=unit(0.15,"cm"),
                           angle=20),
               lwd=0.75)+
  geom_point(data=psubFH1_final,
             aes(x=as.numeric(rownames(psubFH1_final)),
                 y=0,
                 col=fact_abund2),
             show.legend = F,
             pch=4)+
  scale_alpha_manual(values=c(0,0,1))+
  scale_color_manual(values=c("black","NA","NA"))+
  guides(color=F,
         fill =F,
         alpha=F
  )+
  annotate("text",x=250,y=-7,size=2.75,label=paste("Day 15\nOTUs: ",abotuBday15,"%\nReads: ",abreadsBday15,"%",sep = ""))+
  ylim(-13,13)+
  coord_flip()
ggsave("Figures/EDF_10c.pdf",width=70,height=140,unit="mm",device=cairo_pdf)

### 13d. Extended Data Figure 10d: Deseq bacteria day 30 ----
deseqH2$otu<-rownames(deseqH2)
deseqH2_int<-right_join(deseqH2,deseqH0[,9:10],by="otu")
psubFH2_init<-filter(deseqH2_int,
                     padj < 0.05)
rownames(psubFH2_init)<-psubFH2_init$otu
## filter otu table to keep only relevant harvest
otutab_for_mng_H2<-otutab_for_mng[,which(map16s_wmet_wdna$harvest=="30")]
otutab_for_mng_H2$otu<-rownames(otutab_for_mng_H2)
otusubF_H2<-filter(otutab_for_mng_H2,
                   otu %in% psubFH2_init$otu)
psubFH2<-filter(psubFH2_init,
                otu %in% otusubF_H2$otu) 
rownames(otusubF_H2)<-otusubF_H2$otu
rownames(psubFH2)<-psubFH2$otu
otusubF_H2<-otusubF_H2[match(rownames(psubFH2),
                             rownames(otusubF_H2)),]
all.equal(rownames(otusubF_H2),rownames(psubFH2))
psubFH2$ab_rar1000<-rowSums(otusubF_H2[,1:6])
psubFH2$ab_rar1000_pc<-(psubFH2$ab_rar1000/sum(otutab_for_mng_H2[,1:6]))*100 ### abundance of the OTU in the total rarefied dataset in %

# Rearrange the dataset by decreasing Phyla and Fold-change for readability
psubFH2_final<-arrange(psubFH2,desc(Phyla),
                       (-log2FoldChange))
rownames(psubFH2_final)<-c(1:length(rownames(psubFH2_final)))
psubFH2_final$fact_abund<-ifelse(psubFH2_final$ab_rar1000_pc>0.5,
                                 "High",
                                 "Low")
psubFH2_final$fact_abund2<-ifelse(rownames(psubFH2_final) %in% grep("*Nitro*",psubFH2_final$taxonomy),
                                  "Nitrifier", 
                                  psubFH2_final$fact_abund)
abotuBday30<-round_any(100*length(psubFH2$otu)/length(which(rowSums(otutab_for_mng_H2[,-7])!=0)),0.01)
abreadsBday30<-round_any(sum(psubFH2_final$ab_rar1000_pc),0.01)

ggplot(psubFH2_final,
       aes(x=as.numeric(rownames(psubFH2_final)),
           y=-log2FoldChange))+
  theme_bw()+
  xlab(paste(length(psubFH2_final$otu),"bacterial OTUs affected by soil transfer"))+
  ylab(ds2b_yl)+
  geom_bar(aes(fill=Phyla),
           stat="identity",
           width=1)+
  scale_fill_manual(values=phyla.pal)+
theme(legend.position="bottom",
      legend.box="vertical",
      axis.text.y=element_blank(),
      axis.ticks.y=element_blank(),
      legend.key.size=unit(0.4,"cm"),
      text=element_text(size=10),
      panel.grid=element_blank(),
      panel.background=element_rect(fill="NA")
)+
  geom_segment(data=psubFH2_final,
               aes(x=as.numeric(rownames(psubFH2_final)),
                   xend=as.numeric(rownames(psubFH2_final)),
                   y=-1.5,
                   yend=0,
                   alpha=fact_abund2),
               arrow=arrow(type = "closed",
                           length=unit(0.15,"cm"),
                           angle=20),
               lwd=0.75)+
  geom_point(data=psubFH2_final,
             aes(x=as.numeric(rownames(psubFH2_final)),
                 y=0,
                 col=fact_abund2),
             show.legend = F,
             pch=4)+
  scale_alpha_manual(values=c(0,0,1))+
  scale_color_manual(values=c("black","NA","NA"))+
  guides(color=F,
         fill =F,
         alpha=F
  )+
  annotate("text",x=375,y=-7,size=2.75,label=paste("Day 30\nOTUs: ",abotuBday30,"%\nReads: ",abreadsBday30,"%",sep = ""))+
  ylim(-13,13)+
  coord_flip()
ggsave("Figures/EDF_10d.pdf",width=70,height=140,unit="mm",device=cairo_pdf)

  
### 13e. Extended Data Figure 10e: Deseq bacteria day 71 ----
deseqH3$otu<-rownames(deseqH3)
deseqH3_int<-right_join(deseqH3,deseqH0[,9:10],by="otu")
psubFH3_init<-filter(deseqH3_int,
                     padj < 0.05)
rownames(psubFH3_init)<-psubFH3_init$otu
## filter otu table to keep only relevant harvest
otutab_for_mng_H3<-otutab_for_mng[,which(map16s_wmet_wdna$harvest=="71")]
otutab_for_mng_H3$otu<-rownames(otutab_for_mng_H3)
otusubF_H3<-filter(otutab_for_mng_H3,
                   otu %in% psubFH3_init$otu)
psubFH3<-filter(psubFH3_init,
                otu %in% otusubF_H3$otu)
rownames(otusubF_H3)<-otusubF_H3$otu
rownames(psubFH3)<-psubFH3$otu
otusubF_H3<-otusubF_H3[match(rownames(psubFH3),
                             rownames(otusubF_H3)),]
all.equal(rownames(otusubF_H3),rownames(psubFH3))
psubFH3$ab_rar1000<-rowSums(otusubF_H3[,1:6])
psubFH3$ab_rar1000_pc<-(psubFH3$ab_rar1000/sum(otutab_for_mng_H3[,1:6]))*100 ### abundance of the OTU in the total rarefied dataset in %

# Rearrange the dataset by decreasing Phyla and Fold-change for readability
psubFH3_final<-arrange(psubFH3,desc(Phyla),
                       (-log2FoldChange))
rownames(psubFH3_final)<-c(1:length(rownames(psubFH3_final))) 
psubFH3_final$fact_abund<-ifelse(psubFH3_final$ab_rar1000_pc>0.5,
                                 "High",
                                 "Low")
psubFH3_final$fact_abund2<-ifelse(rownames(psubFH3_final) %in% grep("*Nitro*",psubFH3_final$taxonomy),
                                  "Nitrifier", 
                                  psubFH3_final$fact_abund)
abotuBday71<-round_any(100*length(psubFH3$otu)/length(which(rowSums(otutab_for_mng_H3[,-7])!=0)),0.01)
abreadsBday71<-round_any(sum(psubFH3_final$ab_rar1000_pc),0.01)
ggplot(psubFH3_final,
       aes(x=as.numeric(rownames(psubFH3_final)),
           y=-log2FoldChange))+
  theme_bw()+
  xlab(paste(length(psubFH3_final$otu),"bacterial OTUs affected by soil transfer"))+
  ylab(ds2b_yl)+
  geom_bar(aes(fill=Phyla),
           stat="identity",
           width=1)+
  scale_fill_manual(values=phyla.pal)+
theme(legend.position="bottom",
      legend.box="vertical",
      axis.text.y=element_blank(),
      axis.ticks.y=element_blank(),
      legend.key.size=unit(0.4,"cm"),
      text=element_text(size=10),
      panel.grid=element_blank(),
      panel.background=element_rect(fill="NA")
)+
  geom_segment(data=psubFH3_final,
               aes(x=as.numeric(rownames(psubFH3_final)),
                   xend=as.numeric(rownames(psubFH3_final)),
                   y=-1.5,
                   yend=0,
                   alpha=fact_abund2),
               arrow=arrow(type = "closed",
                           length=unit(0.15,"cm"),
                           angle=20),
               lwd=0.75)+
  geom_point(data=psubFH3_final,
             aes(x=as.numeric(rownames(psubFH3_final)),
                 y=0,
                 col=fact_abund2),
             show.legend = F,
             pch=4)+
  scale_alpha_manual(values=c(0,0,1))+
  scale_color_manual(values=c("black","NA","NA"))+
  guides(color=F,
         fill =F,
         alpha=F
  )+
  annotate("text",x=375,y=-7,size=2.75,label=paste("Day 75\nOTUs: ",abotuBday71,"%\nReads: ",abreadsBday71,"%",sep = ""))+
  ylim(-13,13)+
  coord_flip()
ggsave("Figures/EDF_10e.pdf",width=70,height=140,unit="mm",device=cairo_pdf)

### 13f. Extended Data Figure 10f: Deseq bacteria day 161 ----
deseqH4$otu<-rownames(deseqH4)
deseqH4_int<-right_join(deseqH4,deseqH0[,9:10],by="otu")
psubFH4_init<-filter(deseqH4_int,
                     padj < 0.05)
rownames(psubFH4_init)<-psubFH4_init$otu
## filter otu table to keep only relevant harvest
otutab_for_mng_H4<-otutab_for_mng[,which(map16s_wmet_wdna$harvest=="161")]
otutab_for_mng_H4$otu<-rownames(otutab_for_mng_H4)
otusubF_H4<-filter(otutab_for_mng_H4,
                   otu %in% psubFH4_init$otu)
psubFH4<-filter(psubFH4_init,
                otu %in% otusubF_H4$otu)
rownames(otusubF_H4)<-otusubF_H4$otu
rownames(psubFH4)<-psubFH4$otu
otusubF_H4<-otusubF_H4[match(rownames(psubFH4),
                             rownames(otusubF_H4)),]
all.equal(rownames(otusubF_H4),rownames(psubFH4))
psubFH4$ab_rar1000<-rowSums(otusubF_H4[,1:6])
psubFH4$ab_rar1000_pc<-(psubFH4$ab_rar1000/sum(otutab_for_mng_H4[,1:6]))*100 ### abundance of the OTU in the total rarefied dataset in %

# Rearrange the dataset by decreasing Phyla and Fold-change for readability
psubFH4_final<-arrange(psubFH4,desc(Phyla),
                       (-log2FoldChange))
rownames(psubFH4_final)<-c(1:length(rownames(psubFH4_final))) 
psubFH4_final$fact_abund<-ifelse(psubFH4_final$ab_rar1000_pc>0.5,
                                 "High",
                                 "Low")
psubFH4_final$fact_abund2<-ifelse(rownames(psubFH4_final) %in% grep("*Nitro*",psubFH4_final$taxonomy),
                                  "Nitrifier", 
                                  psubFH4_final$fact_abund)
abotuBday161<-round_any(100*length(psubFH4$otu)/length(which(rowSums(otutab_for_mng_H4[,-7])!=0)),0.01)
abreadsBday161<-round_any(sum(psubFH4_final$ab_rar1000_pc),0.01)

ggplot(psubFH4_final,
       aes(x=as.numeric(rownames(psubFH4_final)),
           y=-log2FoldChange))+
  theme_bw()+
  xlab(paste(length(psubFH4_final$otu),"bacterial OTUs affected by soil transfer"))+
  ylab(ds2b_yl)+
  geom_bar(aes(fill=Phyla),
           stat="identity",
           width=1)+
  scale_fill_manual(values=phyla.pal)+
theme(legend.position="bottom",
      legend.box="vertical",
      axis.text.y=element_blank(),
      axis.ticks.y=element_blank(),
      legend.key.size=unit(0.4,"cm"),
      text=element_text(size=10),
      panel.grid=element_blank(),
      panel.background=element_rect(fill="NA")
)+
  geom_segment(data=psubFH4_final,
               aes(x=as.numeric(rownames(psubFH4_final)),
                   xend=as.numeric(rownames(psubFH4_final)),
                   y=-1.5,
                   yend=0,
                   alpha=fact_abund2),
               arrow=arrow(type = "closed",
                           length=unit(0.15,"cm"),
                           angle=20),
               lwd=0.75)+
  geom_point(data=psubFH4_final,
             aes(x=as.numeric(rownames(psubFH4_final)),
                 y=0,
                 col=fact_abund2),
             show.legend = F,
             pch=4)+
  scale_alpha_manual(values=c(0,0,1))+
  scale_color_manual(values=c("black","NA","NA"))+
  guides(color=F,
         fill =F,
         alpha=F
  )+
  annotate("text",x=425,y=-7,size=2.75,label=paste("Day 161\nOTUs: ",abotuBday161,"%\nReads: ",abreadsBday161,"%",sep = ""))+
  ylim(-13,13)+
  coord_flip()
ggsave("Figures/EDF_10f.pdf",width=70,height=140,unit="mm",device=cairo_pdf)

### 13g. Extended Data Figure 10g: Proportion of OTUs affected or not by soil transfer ----
otu_tab_ctrl<-subset(otutab,select=names(otutab) %in% 
                       as.character(map16s_wmet$SampleID[which(map16s_wmet$Treatment=="Control")]))
otu_tab_ctrl<-otu_tab_ctrl[-(which(rowSums(otu_tab_ctrl)==0)),]

otu_tab_inoc<-subset(otutab,select=colnames(otutab) %in% 
                       as.character(map16s_wmet$SampleID[which(map16s_wmet$Treatment=="Soil transfer")]))
otu_tab_inoc<-otu_tab_inoc[-(which(rowSums(otu_tab_inoc)==0)),]

deseq_nochange<-subset(deseqF,pvalue>max(psubF$pvalue))

otus_not_changing_c<-rownames(otu_tab_ctrl)[which(rownames(otu_tab_ctrl) %in% rownames(deseq_nochange))]
otus_not_changing_i<-rownames(otu_tab_inoc)[which(rownames(otu_tab_inoc) %in% rownames(deseq_nochange))]

total_inoc_changing<-colSums(otu_tab_inoc[which(rownames(otu_tab_inoc) %in% psubF$otu),])/5000
total_inoc_not_changing_pre<-colSums(otu_tab_inoc[which(rownames(otu_tab_inoc) %in% rownames(deseq_nochange)),])/5000

total_ctrl_changing<-colSums(otu_tab_ctrl[which(rownames(otu_tab_ctrl) %in% psubF$otu),])/5000
total_ctrl_not_changing_pre<-colSums(otu_tab_ctrl[which(rownames(otu_tab_ctrl) %in% rownames(deseq_nochange)),])/5000

otu_only_ctrl<-otus_not_changing_c[-which(otus_not_changing_c %in% otus_not_changing_i)]
total_only_ctrl<-colSums(otu_tab_ctrl[which(rownames(otu_tab_ctrl) %in% otu_only_ctrl),])/5000
total_ctrl_not_changing<-total_ctrl_not_changing_pre-total_only_ctrl

otu_only_inoc<-otus_not_changing_i[-which(otus_not_changing_i %in% otus_not_changing_c)]
total_only_inoc<-colSums(otu_tab_inoc[which(rownames(otu_tab_inoc) %in% otu_only_inoc),])/5000
total_inoc_not_changing<-total_inoc_not_changing_pre-total_only_inoc

ch_prop<-data.frame(changing=c(total_ctrl_changing,total_inoc_changing),
                    not_changing=c(total_ctrl_not_changing,total_inoc_not_changing),
                    only=c(total_only_ctrl,total_only_inoc))
ch_prop$SampleID<-rownames(ch_prop)
ch<-left_join(ch_prop,map16s_wmet[,c(1,5,6)],by='SampleID')
meltch<-melt(ch)
meltch$Harvest<-droplevels(meltch$Harvest)
levels(meltch$Harvest)<-c("1","15","30","71","161")
names(meltch)[4]<-"OTUs"
levels(meltch$OTUs)<-c("Changing","Unaffected","Specific")
ggplot(meltch,aes(x=Harvest))+
  geom_bar(aes(weight=value,
               fill=OTUs),
           position= 'fill')+
  xlab("Days since inoculation")+
  ylab("Relative abundance")+
  facet_wrap(~Treatment)+
  theme_bw()+
  scale_fill_brewer(type="qual",palette = 2)+ 
  theme(panel.grid=element_blank())
ggsave("Figures/EDF_10g.pdf",width=12,height=8,unit="cm")

#### 14. Table 1: Multiple linear regressions ----
rfmap_mod<-as.data.frame(scale(rfmap[,-which(names(rfmap)=="SampleID")])) # scale and center all variables 
par(mfrow=c(2,2))

lm_base<-lm(CO2_rate_detrended~AOA+AOB+Bacteroidetes+WS3,data=rfmap_mod)
plot(lm_base)
summary(lm_base)

lm_a<-lm(CO2_rate_detrended~AOA+AOB+Bacteroidetes+WS3+Cmic_total+X16S_DL,data=rfmap_mod)
plot(lm_a)
summary(lm_a)


lm_b<-lm(CO2_rate_detrended~AOA+AOB+Bacteroidetes+WS3+TDC+NO3_N+NH4_N+DIN,data=rfmap_mod)
plot(lm_b)
summary(lm_b)

lm_c<-lm(CO2_rate_detrended~AOA+AOB+Bacteroidetes+WS3+Cmic_total+X16S_DL+TDC+NO3_N+NH4_N+DIN,data=rfmap_mod)
plot(lm_c)
summary(lm_c)

lm_d<-lm(CO2_rate_detrended~Cmic_total+X16S_DL+TDC+NO3_N+NH4_N+DIN,data=rfmap_mod)
plot(lm_d)
summary(lm_d)

lm_e<-lm(CO2_rate_detrended~TDC+NO3_N+NH4_N+DIN,data=rfmap_mod)
plot(lm_e)
summary(lm_e)

lm_f<-lm(CO2_rate_detrended~Cmic_total+X16S_DL,data=rfmap_mod)
plot(lm_f)
summary(lm_f)

Table_1<-data.frame(Model=c("Selected","Selected+biomass","Selected+chemistry","Selected+biomass+chemistry",
                                           "Chemistry+biomass","Chemistry","Biomass"),
                                   AICc=c(AICc(lm_base),
                                         AICc(lm_a),
                                         AICc(lm_b),
                                         AICc(lm_c),
                                         AICc(lm_d),
                                         AICc(lm_e),
                                         AICc(lm_f)),
                                   Rsquared=c(RsquareAdj(lm_base)$r.squared[1],
                                              RsquareAdj(lm_a)$r.squared[1],
                                              RsquareAdj(lm_b)$r.squared[1],
                                              RsquareAdj(lm_c)$r.squared[1],
                                              RsquareAdj(lm_d)$r.squared[1],
                                              RsquareAdj(lm_e)$r.squared[1],
                                              RsquareAdj(lm_f)$r.squared[1]),
                                   Rsquared.adj=c(RsquareAdj(lm_base)$adj.r.squared[1],
                                              RsquareAdj(lm_a)$adj.r.squared[1],
                                              RsquareAdj(lm_b)$adj.r.squared[1],
                                              RsquareAdj(lm_c)$adj.r.squared[1],
                                              RsquareAdj(lm_d)$adj.r.squared[1],
                                              RsquareAdj(lm_e)$adj.r.squared[1],
                                              RsquareAdj(lm_f)$adj.r.squared[1]))
write.table(Table_1,"Figures/Table_1.txt")



#### 15. Information supporting response to referees ----
### 15a. Response to referees letter statistics: Cumulative respiration including all treatments ----
yedo161<-subset(resp161,soil_type=="Permafrost")
yedo161$inoc<-as.factor(yedo161$inoc)
yedo161$cellulose<-as.factor(yedo161$cellulose)
yedo161$nutrients<-as.factor(yedo161$nutrients)
mod161<-lm(CO2_cum_interp~cellulose*nutrients*inoc,data=yedo161)
plot(mod161)
hist(mod161$residuals)
shapiro.test(mod161$residuals)
bartlett.test(yedo161$CO2_cum_interp,interaction(yedo161$cellulose,yedo161$inoc,yedo161$nutrients))
anova(mod161)
lsmeans(mod161,pairwise~inoc)
lsmeans(mod161,pairwise~cellulose)
lsmeans(mod161,pairwise~nutrients)



### 15b. Response to referees letter statistics: Cellulose consumption in 13C-cellulose amendment treatments ----
### FOM-CO2 production cumulative for C, CN, CF, CNF
# In response to a reviewer comment about the introduction of substrates favouring the enrichment of already-present heterotrophs, and thus explaining the increase in CO2 production with 2.5% soil transfer inoculum, we mentioned 13C-cellulose derived CO2 production as a way of testing this
# We suggest instead that the inoculum introduced more-efficient heterotrophs, which we test by looking at how much of the amended 13C-cellulose is left at the end of the 161 days incubation 
fom<-data.frame(resp_FOM=c(1046.90, # 13C-partitioning data for CO2 production derived from the 13C-labelled cellulose
                           979.09,
                           993.97,
                           906.03,
                           906.35,
                           919.60,
                           973.54,
                           995.18,
                           1051.42,
                           889.26,
                           909.26,
                           906.07,
                           1140.92,
                           1171.46,
                           1164.62),
                N=c(rep("1",6),rep("0",9)),
                F=c(rep(c(rep("1",3),rep("0",3)),2),rep("0",3)),
                soil=c(rep("Y",12),rep("S",3)))
fom$cell<-2000-fom$resp_FOM
mod_fom<-lm(cell~N*F,data=subset(fom,soil=="Y"))
plot(mod_fom)
shapiro.test(resid(mod_fom))
anova(mod_fom)
lsmeans(mod_fom,pairwise~F)
mean(fom$cell[c(13:15)])

mod_fom2<-lm(cell~soil,data=subset(fom, N=="0" & F=="0"))
lsmeans(mod_fom2,pairwise~soil)

### 15c. Response to referees letter Figure: TDC all treatments figure ----
# In response to a reviewer comment, we showed that the decrease in TDC is not due to the introduction of labile C or nutrients, as it was present in all inoculated treatments regardless of cellulose or nutrients addition, and likewise not seen in the same proportions in non-inoculated treatments
dat<-read.csv("Metadata/MonteuxKeuper_extractions.csv")
dat<-subset(dat,soil_type=="Y")
dat$inoculum<-as.factor(dat$inoculum)
levels(dat$inoculum)<-c("No","Yes")
dat$cellulose<-as.factor(dat$cellulose)
dat$nutrients<-as.factor(dat$nutrients)
dat$Addition<-interaction(dat$nutrients,dat$cellulose)
levels(dat$Addition)<-c("None","NPK","13C-Cellulose","NPK + 13C-cellulose")

yl_reb_tdc<-expression(paste('TDC mg-C . kg(soil DW)'^'-1')) # y axis label

ggplot(dat,aes(x=as.factor(day),y=TDC,col=inoculum,pch=Addition))+
  guides(col=guide_legend("Soil transfer"))+
  stat_summary(position=position_dodge(0.2))+
  scale_shape_manual(values=c(16,17,15,4))+
  expand_limits(y=c(0,500))+
  ylab(yl_reb_tdc)+
  xlab("Days since transfer")+
  theme_bw()+
  theme(panel.grid=element_blank(),
        strip.background=NULL)+
  scale_colour_manual(values=c("grey70","grey20"))#+facet_grid(~nutrients)
ggsave("Figures/Rebuttal_TDC.pdf",width=170,height=120,unit="mm")

modc<-lm(TDC~inoculum*nutrients*cellulose*day,data=dat)
plot(modc)
shapiro.test(resid(modc))
bartlett.test(dat$TDC,interaction(dat$inoculum,dat$cellulose,dat$nutrients,dat$day))
anova(modc)
